import { Alert as Alert$1, Badge as Badge$1, Breadcrumb as Breadcrumb$1, Button as Button$1, Card as Card$1, CardBody as CardBody$1, CardTitle as CardTitle$1, CardText as CardText$1, Collapse as Collapse$1, NavbarBrand, Navbar, Container, Row, Col, NavbarToggler, Nav as Nav$1, UncontrolledDropdown, DropdownToggle, DropdownMenu, Modal as Modal$1, ModalBody as ModalBody$1, ModalFooter as ModalFooter$1, FormGroup, Label, Input as Input$1, Dropdown } from 'reactstrap';
export { BreadcrumbItem, ButtonDropdown, ButtonGroup, ButtonToolbar, CardColumns, CardDeck, CardFooter, CardGroup, CardHeader, CardImg, CardImgOverlay, CardLink, CardSubtitle, Col, Container, Dropdown, DropdownItem, DropdownMenu, DropdownToggle, Fade, Form, FormFeedback, FormGroup, FormText, InputGroup, InputGroupText, Label, ListGroup, ListGroupItem, ListGroupItemHeading, ListGroupItemText, Media, NavItem, NavLink, Navbar, NavbarBrand, NavbarToggler, PaginationItem as PagerItem, PaginationLink as PagerLink, Popover, PopoverBody, PopoverHeader, Row, TabContent, TabPane, Table, Tooltip, UncontrolledAlert, UncontrolledButtonDropdown, UncontrolledCollapse, UncontrolledDropdown, UncontrolledTooltip, Util } from 'reactstrap';
export { useNavScroll } from 'react-use-navscroll';
import React__default, { useState, useCallback, useEffect, createContext, useContext, Fragment } from 'react';
import classNames from 'classnames';
import { Transition } from 'react-transition-group';
import { StickyProvider, Sticky } from 'react-stickup';
import isNumber from 'is-number';
import SelectBase, { components } from 'react-select';
import { useToast, cssTransition, useToastContainer, toast } from 'react-toastify';

const defaultProps = {
  color: 'success',
  isOpen: true,
  fade: true
};
const Alert = _ref => {
  let {
    testId,
    ...props
  } = _ref;
  return React__default.createElement(Alert$1, Object.assign({
    "data-testid": testId
  }, props));
};
Alert.defaultProps = defaultProps;

const Accordion = _ref => {
  let {
    tag = 'div',
    className,
    background,
    iconLeft = false,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('accordion', className, {
    'accordion-background-active': background === 'active',
    'accordion-background-hover': background === 'hover',
    'accordion-left-icon': iconLeft
  });
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }));
};

const AccordionItem = _ref => {
  let {
    tag = 'div',
    className,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('accordion-item', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes
  }));
};

const AccordionHeader = _ref => {
  let {
    className,
    tag = 'button',
    active = false,
    append,
    onToggle,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const toggleClasses = classNames(className, 'accordion-button', {
    collapsed: active
  });
  return React__default.createElement("div", {
    className: 'accordion-header',
    "data-testid": testId
  }, React__default.createElement(Tag, Object.assign({
    "data-bs-toggle": 'collapse',
    "aria-expanded": active ? 'true' : 'false',
    className: toggleClasses,
    onClick: onToggle
  }, attributes, tag === 'button' && {
    type: 'button'
  })), append);
};

const noop = () => {};
const logError = message => {
  if (typeof console !== 'undefined') {
    if (console.error) {
      console.error(message);
    } else {
      console.log(message);
    }
  }
};
const messages = {};
const notifyDeprecation = function (message, options) {
  if (options === void 0) {
    options = {
      once: true
    };
  }
  if (!options.once) {
    logError(message);
  } else {
    if (!messages[message]) {
      logError(message);
      messages[message] = 1;
    }
  }
};
function mapToCssModules(className, cssModules) {
  let finalClassNames = className == null ? '' : className;
  if (!cssModules) {
    return finalClassNames;
  }
  return finalClassNames.split(' ').map(klass => cssModules[klass] ?? klass).join(' ');
}
function pick(obj, keys) {
  const keysArray = Array.isArray(keys) ? keys : [keys];
  const newObj = {};
  for (const key of keysArray) {
    if (key in obj) {
      newObj[key] = obj[key];
    }
  }
  return newObj;
}
function omit(obj, keys) {
  const keysLookup = new Set(Array.isArray(keys) ? keys : [keys]);
  const newObj = {};
  for (const key in obj) {
    if (!keysLookup.has(key)) {
      newObj[key] = obj[key];
    }
  }
  return newObj;
}

// Taken from Reactstrap utils.js which are tken from bootstrap sass
const TransitionTimeouts = {
  // $transition-fade
  Fade: 150,
  // $transition-collapse
  Collapse: 350,
  // $modal-transition
  Modal: 300,
  // $carousel-transition
  Carousel: 600
};
// taken from Reactstrap utils.js
const TransitionsKeys = ['in', 'mountOnEnter', 'unmountOnExit', 'appear', 'enter', 'exit', 'timeout', 'onEnter', 'onEntering', 'onEntered', 'onExit', 'onExiting', 'onExited'];

// hardcode these entries to avoid leaks
const transitionStatusToClassHash = {
  entering: 'collapsing',
  entered: 'collapse show',
  exiting: 'collapsing',
  exited: 'collapse'
};
function getTransitionClass(status) {
  return transitionStatusToClassHash[status] || 'collapse';
}
function getHeight(node) {
  return node.scrollHeight;
}
const AccordionBody = _ref => {
  let {
    className,
    listClassName,
    tag = 'div',
    active = false,
    children,
    timeout = TransitionTimeouts.Collapse,
    ...attributes
  } = _ref;
  const [height, setHeight] = useState(null);
  const onEntering = useCallback((node, isAppearing) => {
    setHeight(getHeight(node));
    attributes.onEntering == null ? void 0 : attributes.onEntering(node, isAppearing);
  }, [attributes.onEntering]);
  const onEntered = useCallback((node, isAppearing) => {
    setHeight(null);
    attributes.onEntered == null ? void 0 : attributes.onEntered(node, isAppearing);
  }, [attributes.onEntered]);
  const onExit = useCallback(node => {
    setHeight(getHeight(node));
    attributes.onExit == null ? void 0 : attributes.onExit(node);
  }, [attributes.onExit]);
  const onExiting = useCallback(node => {
    setHeight(0);
    attributes.onExiting == null ? void 0 : attributes.onExiting(node);
  }, [attributes.onExiting]);
  const onExited = useCallback(node => {
    setHeight(null);
    attributes.onExited == null ? void 0 : attributes.onExited(node);
  }, [attributes.onExited]);
  const Tag = tag;
  const transitionProps = pick(attributes, TransitionsKeys);
  const childProps = omit(attributes, TransitionsKeys);
  return React__default.createElement(Transition, Object.assign({}, transitionProps, {
    timeout: timeout,
    in: active,
    onEntering: onEntering,
    onEntered: onEntered,
    onExit: onExit,
    onExiting: onExiting,
    onExited: onExited
  }), status => {
    const transitionClass = getTransitionClass(status);
    const classes = classNames(className, transitionClass);
    const listClasses = classNames(listClassName, 'accordion-body');
    const style = height == null ? null : {
      height
    };
    return React__default.createElement(Tag, Object.assign({
      className: classes,
      style: {
        ...childProps.style,
        ...style
      }
    }, childProps), React__default.createElement("div", {
      className: listClasses
    }, children));
  });
};
// }

const AvatarContainer = _ref => {
  let {
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('d-flex align-items-center justify-content-around flex-wrap flex-sm-nowrap', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClasses,
    "data-testid": testId
  }));
};

const AvatarGroupContainer = _ref => {
  let {
    className,
    tag = 'ul',
    wrapperClassName,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('avatar-group-stacked', wrapperClassName);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClasses,
    "data-testid": testId
  }));
};

const AvatarExtraText = _ref => {
  let {
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('extra-text', className);
  return React__default.createElement(Tag, Object.assign({
    className: wrapperClass
  }, attributes, {
    "data-testid": testId
  }));
};

const AvatarIcon = _ref => {
  let {
    className,
    tag = 'div',
    size = 'md',
    href,
    color,
    innerRef,
    testId,
    children,
    ...attributes
  } = _ref;
  const Tag = tag;
  const typeClass = classNames('avatar', {
    [`size-${size}`]: size,
    [`avatar-${color}`]: color
  });
  if (href) {
    return React__default.createElement("a", Object.assign({
      href: href
    }, attributes, {
      className: typeClass,
      ref: innerRef,
      "data-testid": testId
    }), children);
  }
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: typeClass,
    "data-testid": testId
  }), children);
};

const AvatarPresence = _ref => {
  let {
    className,
    tag = 'div',
    presence,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const typeClass = classNames('avatar-presence', {
    presence
  });
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: typeClass,
    "data-testid": testId
  }));
};

const AvatarStatus = _ref => {
  let {
    className,
    tag = 'div',
    status,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const typeClass = classNames('avatar-status', {
    status
  });
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: typeClass,
    "data-testid": testId
  }));
};

const AvatarWrapper = _ref => {
  let {
    className,
    tag = 'div',
    extra,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('avatar-wrapper', className, {
    [`avatar-extra-${extra}`]: extra
  });
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClass,
    "data-testid": testId
  }));
};

const Badge = _ref => {
  let {
    color = 'secondary',
    pill = false,
    tag = 'span',
    children,
    testId,
    ...attributes
  } = _ref;
  return React__default.createElement(Badge$1, Object.assign({
    color: color,
    pill: pill,
    tag: tag
  }, attributes, {
    "data-testid": testId
  }), children);
};

const Breadcrumb = _ref => {
  let {
    className,
    listClassName,
    dark,
    'aria-label': label,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames(className, 'breadcrumb-container');
  const listClasses = classNames(listClassName, {
    dark
  });
  const ariaLabel = label ?? 'breadcrumb';
  return React__default.createElement(Breadcrumb$1, Object.assign({
    className: classes,
    listClassName: listClasses,
    "aria-label": ariaLabel,
    "data-testid": testId
  }, attributes));
};

const Button = _ref => {
  let {
    tag = 'button',
    icon = false,
    color = '',
    className,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames(className, {
    'btn-icon': icon
  });
  const ariaAttributes = {
    ...(attributes.disabled && {
      'aria-disabled': true
    })
  };
  const baseProps = {
    color,
    tag
  };
  return React__default.createElement(Button$1, Object.assign({
    className: classes,
    "data-testid": testId
  }, baseProps, attributes, ariaAttributes));
};

const Forward = _ref => {
  let {
    className,
    scrollToRef,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames(className, 'forward');
  return React__default.createElement("a", Object.assign({
    className: classes,
    onClick: () => {
      var _scrollToRef$current;
      return (_scrollToRef$current = scrollToRef.current) == null ? void 0 : _scrollToRef$current.scrollIntoView({
        behavior: 'smooth',
        block: 'start'
      });
    },
    "data-testid": testId
  }, attributes), children);
};

const Callout = _ref => {
  let {
    children,
    color = '',
    highlight = false,
    className,
    detailed,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, color, 'callout', {
    'callout-highlight': highlight,
    'callout-more': detailed
  });
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), children);
};

const CalloutText = _ref => {
  let {
    bigText = false,
    children,
    className,
    tag = 'p',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, {
    'callout-big-text': bigText
  });
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), children);
};

const CalloutTitle = _ref => {
  let {
    children,
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'callout-title');
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), children);
};

const Card = _ref => {
  let {
    tag = 'div',
    teaser,
    spacing,
    noWrapper = false,
    wrapperClassName,
    testId,
    ...attributes
  } = _ref;
  const wrapperClasses = classNames('card-wrapper', wrapperClassName, {
    'card-space': spacing,
    'card-teaser-wrapper': teaser
  });
  const cardClasses = classNames(attributes.className, {
    'card-teaser': teaser
  });
  if (noWrapper) {
    return React__default.createElement(Card$1, Object.assign({}, attributes, {
      className: cardClasses,
      tag: tag,
      "data-testid": testId
    }));
  }
  return React__default.createElement("div", {
    className: wrapperClasses,
    "data-testid": testId
  }, React__default.createElement(Card$1, Object.assign({}, attributes, {
    className: cardClasses,
    tag: tag
  })));
};

const CardBody = _ref => {
  let {
    tag = 'div',
    testId,
    ...props
  } = _ref;
  return React__default.createElement(CardBody$1, Object.assign({}, props, {
    tag: tag,
    "data-testid": testId
  }));
};

const CardTitle = props => {
  return React__default.createElement(CardTitle$1, Object.assign({}, props, {
    "data-testid": props.testId
  }));
};

const CardText = props => {
  return React__default.createElement(CardText$1, Object.assign({}, props, {
    "data-testid": props.testId
  }));
};

const iconList = {
  'it-arrow-down-circle': true,
  'it-arrow-down-triangle': true,
  'it-arrow-down': true,
  'it-arrow-left-circle': true,
  'it-arrow-left-triangle': true,
  'it-arrow-left': true,
  'it-arrow-right-circle': true,
  'it-arrow-right-triangle': true,
  'it-arrow-right': true,
  'it-arrow-up-circle': true,
  'it-arrow-up-triangle': true,
  'it-arrow-up': true,
  'it-ban': true,
  'it-behance': true,
  'it-bookmark': true,
  'it-box': true,
  'it-burger': true,
  'it-calendar': true,
  'it-camera': true,
  'it-card': true,
  'it-chart-line': true,
  'it-check-circle': true,
  'it-check': true,
  'it-chevron-left': true,
  'it-chevron-right': true,
  'it-clip': true,
  'it-clock': true,
  'it-close-big': true,
  'it-close-circle': true,
  'it-close': true,
  'it-code-circle': true,
  'it-collapse': true,
  'it-comment': true,
  'it-copy': true,
  'it-delete': true,
  'it-designers-italia': true,
  'it-download': true,
  'it-error': true,
  'it-exchange-circle': true,
  'it-expand': true,
  'it-external-link': true,
  'it-facebook-square': true,
  'it-facebook': true,
  'it-figma-square': true,
  'it-figma': true,
  'it-file-audio': true,
  'it-file-compressed': true,
  'it-file-csv': true,
  'it-file-json': true,
  'it-file-odp': true,
  'it-file-ods': true,
  'it-file-odt': true,
  'it-file-pdf-ext': true,
  'it-file-pdf': true,
  'it-file-sheet': true,
  'it-file-slides': true,
  'it-file-txt': true,
  'it-file-video': true,
  'it-file-xml': true,
  'it-file': true,
  'it-files': true,
  'it-flag': true,
  'it-flickr-square': true,
  'it-flickr': true,
  'it-folder': true,
  'it-fullscreen': true,
  'it-funnel': true,
  'it-github': true,
  'it-google': true,
  'it-hearing': true,
  'it-help-circle': true,
  'it-help': true,
  'it-horn': true,
  'it-inbox': true,
  'it-info-circle': true,
  'it-instagram': true,
  'it-key': true,
  'it-less-circle': true,
  'it-link': true,
  'it-linkedin-square': true,
  'it-linkedin': true,
  'it-list': true,
  'it-lock': true,
  'it-locked': true,
  'it-logout': true,
  'it-mail-open': true,
  'it-mail': true,
  'it-map-marker-circle': true,
  'it-map-marker-minus': true,
  'it-map-marker-plus': true,
  'it-map-marker': true,
  'it-mastodon-square': true,
  'it-mastodon': true,
  'it-maximize-alt': true,
  'it-maximize': true,
  'it-medium-square': true,
  'it-medium': true,
  'it-minimize': true,
  'it-minus-circle': true,
  'it-minus': true,
  'it-more-actions': true,
  'it-more-items': true,
  'it-note': true,
  'it-open-source': true,
  'it-pa': true,
  'it-password-invisible': true,
  'it-password-visible': true,
  'it-pencil': true,
  'it-piattaforme': true,
  'it-pin': true,
  'it-pinterest-square': true,
  'it-pinterest': true,
  'it-plug': true,
  'it-plus-circle': true,
  'it-plus': true,
  'it-presentation': true,
  'it-print': true,
  'it-quora-square': true,
  'it-quora': true,
  'it-reddit-square': true,
  'it-reddit': true,
  'it-refresh': true,
  'it-restore': true,
  'it-rss-square': true,
  'it-rss': true,
  'it-search': true,
  'it-settings': true,
  'it-share': true,
  'it-slack-square': true,
  'it-slack': true,
  'it-snapchat-square': true,
  'it-snapchat': true,
  'it-software': true,
  'it-stackexchange-square': true,
  'it-stackexchange': true,
  'it-stackoverflow-square': true,
  'it-stackoverflow': true,
  'it-star-full': true,
  'it-star-outline': true,
  'it-team-digitale': true,
  'it-telegram': true,
  'it-telephone': true,
  'it-tiktok-square': true,
  'it-tiktok': true,
  'it-tool': true,
  'it-twitter-square': true,
  'it-twitter': true,
  'it-unlocked': true,
  'it-upload': true,
  'it-user': true,
  'it-video': true,
  'it-vimeo-square': true,
  'it-vimeo': true,
  'it-warning-circle': true,
  'it-warning': true,
  'it-whatsapp-square': true,
  'it-whatsapp': true,
  'it-wifi': true,
  'it-youtube': true,
  'it-zoom-in': true,
  'it-zoom-out': true
};
const loadIcon = name => {
  switch (name) {
    case 'it-arrow-down-circle':
      {
        return import('./ItArrowDownCircle-55655d45.js');
      }
    case 'it-arrow-down-triangle':
      {
        return import('./ItArrowDownTriangle-6c32730e.js');
      }
    case 'it-arrow-down':
      {
        return import('./ItArrowDown-6f658a7a.js');
      }
    case 'it-arrow-left-circle':
      {
        return import('./ItArrowLeftCircle-460a8b10.js');
      }
    case 'it-arrow-left-triangle':
      {
        return import('./ItArrowLeftTriangle-10002efe.js');
      }
    case 'it-arrow-left':
      {
        return import('./ItArrowLeft-128230fd.js');
      }
    case 'it-arrow-right-circle':
      {
        return import('./ItArrowRightCircle-aa9dad72.js');
      }
    case 'it-arrow-right-triangle':
      {
        return import('./ItArrowRightTriangle-5a3357eb.js');
      }
    case 'it-arrow-right':
      {
        return import('./ItArrowRight-7e29c42e.js');
      }
    case 'it-arrow-up-circle':
      {
        return import('./ItArrowUpCircle-a99c38eb.js');
      }
    case 'it-arrow-up-triangle':
      {
        return import('./ItArrowUpTriangle-b746e6b6.js');
      }
    case 'it-arrow-up':
      {
        return import('./ItArrowUp-26b7fb4a.js');
      }
    case 'it-ban':
      {
        return import('./ItBan-97c35a5e.js');
      }
    case 'it-behance':
      {
        return import('./ItBehance-64f97a91.js');
      }
    case 'it-bookmark':
      {
        return import('./ItBookmark-28f07a62.js');
      }
    case 'it-box':
      {
        return import('./ItBox-b3afec68.js');
      }
    case 'it-burger':
      {
        return import('./ItBurger-1c2f37ad.js');
      }
    case 'it-calendar':
      {
        return import('./ItCalendar-159c86dd.js');
      }
    case 'it-camera':
      {
        return import('./ItCamera-33261d23.js');
      }
    case 'it-card':
      {
        return import('./ItCard-db4df78f.js');
      }
    case 'it-chart-line':
      {
        return import('./ItChartLine-84eb1ba4.js');
      }
    case 'it-check-circle':
      {
        return import('./ItCheckCircle-ad8feee5.js');
      }
    case 'it-check':
      {
        return import('./ItCheck-4981754b.js');
      }
    case 'it-chevron-left':
      {
        return import('./ItChevronLeft-2f284080.js');
      }
    case 'it-chevron-right':
      {
        return import('./ItChevronRight-87c6fe64.js');
      }
    case 'it-clip':
      {
        return import('./ItClip-a676bf12.js');
      }
    case 'it-clock':
      {
        return import('./ItClock-dafc8ba9.js');
      }
    case 'it-close-big':
      {
        return import('./ItCloseBig-0e1f3a30.js');
      }
    case 'it-close-circle':
      {
        return import('./ItCloseCircle-8d6eac1e.js');
      }
    case 'it-close':
      {
        return import('./ItClose-1fd3de96.js');
      }
    case 'it-code-circle':
      {
        return import('./ItCodeCircle-c2bf33a6.js');
      }
    case 'it-collapse':
      {
        return import('./ItCollapse-320e95dd.js');
      }
    case 'it-comment':
      {
        return import('./ItComment-91e2b19d.js');
      }
    case 'it-copy':
      {
        return import('./ItCopy-3d170336.js');
      }
    case 'it-delete':
      {
        return import('./ItDelete-6dc32921.js');
      }
    case 'it-designers-italia':
      {
        return import('./ItDesignersItalia-ca69930d.js');
      }
    case 'it-download':
      {
        return import('./ItDownload-0ee4c4db.js');
      }
    case 'it-error':
      {
        return import('./ItError-ed36de7d.js');
      }
    case 'it-exchange-circle':
      {
        return import('./ItExchangeCircle-369f350e.js');
      }
    case 'it-expand':
      {
        return import('./ItExpand-2933302f.js');
      }
    case 'it-external-link':
      {
        return import('./ItExternalLink-e1a8998b.js');
      }
    case 'it-facebook-square':
      {
        return import('./ItFacebookSquare-46b79b9a.js');
      }
    case 'it-facebook':
      {
        return import('./ItFacebook-c506ef20.js');
      }
    case 'it-figma-square':
      {
        return import('./ItFigmaSquare-1d49b708.js');
      }
    case 'it-figma':
      {
        return import('./ItFigma-e72823fd.js');
      }
    case 'it-file-audio':
      {
        return import('./ItFileAudio-7f5e8af7.js');
      }
    case 'it-file-compressed':
      {
        return import('./ItFileCompressed-ba6df4cf.js');
      }
    case 'it-file-csv':
      {
        return import('./ItFileCsv-e517c261.js');
      }
    case 'it-file-json':
      {
        return import('./ItFileJson-460dbe3c.js');
      }
    case 'it-file-odp':
      {
        return import('./ItFileOdp-32dc7057.js');
      }
    case 'it-file-ods':
      {
        return import('./ItFileOds-df565b68.js');
      }
    case 'it-file-odt':
      {
        return import('./ItFileOdt-2f8dd326.js');
      }
    case 'it-file-pdf-ext':
      {
        return import('./ItFilePdfExt-8cae6041.js');
      }
    case 'it-file-pdf':
      {
        return import('./ItFilePdf-92aa9158.js');
      }
    case 'it-file-sheet':
      {
        return import('./ItFileSheet-06e138cd.js');
      }
    case 'it-file-slides':
      {
        return import('./ItFileSlides-2b76b56c.js');
      }
    case 'it-file-txt':
      {
        return import('./ItFileTxt-2ef3fb60.js');
      }
    case 'it-file-video':
      {
        return import('./ItFileVideo-0c57b1f9.js');
      }
    case 'it-file-xml':
      {
        return import('./ItFileXml-7b5aec2e.js');
      }
    case 'it-file':
      {
        return import('./ItFile-890ed753.js');
      }
    case 'it-files':
      {
        return import('./ItFiles-87c4b9ff.js');
      }
    case 'it-flag':
      {
        return import('./ItFlag-b05afba9.js');
      }
    case 'it-flickr-square':
      {
        return import('./ItFlickrSquare-1174ac62.js');
      }
    case 'it-flickr':
      {
        return import('./ItFlickr-f2c4c498.js');
      }
    case 'it-folder':
      {
        return import('./ItFolder-c7d0517e.js');
      }
    case 'it-fullscreen':
      {
        return import('./ItFullscreen-4ac628cd.js');
      }
    case 'it-funnel':
      {
        return import('./ItFunnel-c192acdd.js');
      }
    case 'it-github':
      {
        return import('./ItGithub-7a0d05a4.js');
      }
    case 'it-google':
      {
        return import('./ItGoogle-79b02670.js');
      }
    case 'it-hearing':
      {
        return import('./ItHearing-12ce3225.js');
      }
    case 'it-help-circle':
      {
        return import('./ItHelpCircle-945a22d8.js');
      }
    case 'it-help':
      {
        return import('./ItHelp-a0d8ef29.js');
      }
    case 'it-horn':
      {
        return import('./ItHorn-601d3688.js');
      }
    case 'it-inbox':
      {
        return import('./ItInbox-20dc619c.js');
      }
    case 'it-info-circle':
      {
        return import('./ItInfoCircle-9678a562.js');
      }
    case 'it-instagram':
      {
        return import('./ItInstagram-36e2b982.js');
      }
    case 'it-key':
      {
        return import('./ItKey-19bb2ece.js');
      }
    case 'it-less-circle':
      {
        return import('./ItLessCircle-d29a2d4e.js');
      }
    case 'it-link':
      {
        return import('./ItLink-fd03b04e.js');
      }
    case 'it-linkedin-square':
      {
        return import('./ItLinkedinSquare-ed99a4d1.js');
      }
    case 'it-linkedin':
      {
        return import('./ItLinkedin-a36d1188.js');
      }
    case 'it-list':
      {
        return import('./ItList-be369495.js');
      }
    case 'it-lock':
      {
        return import('./ItLock-d006c268.js');
      }
    case 'it-locked':
      {
        return import('./ItLocked-32b4cb60.js');
      }
    case 'it-logout':
      {
        return import('./ItLogout-5828b1d2.js');
      }
    case 'it-mail-open':
      {
        return import('./ItMailOpen-56551d7a.js');
      }
    case 'it-mail':
      {
        return import('./ItMail-4718be3e.js');
      }
    case 'it-map-marker-circle':
      {
        return import('./ItMapMarkerCircle-f6c4c3e2.js');
      }
    case 'it-map-marker-minus':
      {
        return import('./ItMapMarkerMinus-a650f4f5.js');
      }
    case 'it-map-marker-plus':
      {
        return import('./ItMapMarkerPlus-8b5f13d9.js');
      }
    case 'it-map-marker':
      {
        return import('./ItMapMarker-1b807919.js');
      }
    case 'it-mastodon-square':
      {
        return import('./ItMastodonSquare-00461851.js');
      }
    case 'it-mastodon':
      {
        return import('./ItMastodon-26d0f79d.js');
      }
    case 'it-maximize-alt':
      {
        return import('./ItMaximizeAlt-d02f95a3.js');
      }
    case 'it-maximize':
      {
        return import('./ItMaximize-903695e5.js');
      }
    case 'it-medium-square':
      {
        return import('./ItMediumSquare-37ff5cdb.js');
      }
    case 'it-medium':
      {
        return import('./ItMedium-ca57cf37.js');
      }
    case 'it-minimize':
      {
        return import('./ItMinimize-3779814f.js');
      }
    case 'it-minus-circle':
      {
        return import('./ItMinusCircle-9b44bf4a.js');
      }
    case 'it-minus':
      {
        return import('./ItMinus-ce118cf3.js');
      }
    case 'it-more-actions':
      {
        return import('./ItMoreActions-0273bbe8.js');
      }
    case 'it-more-items':
      {
        return import('./ItMoreItems-5ee6516c.js');
      }
    case 'it-note':
      {
        return import('./ItNote-d3988826.js');
      }
    case 'it-open-source':
      {
        return import('./ItOpenSource-34935a22.js');
      }
    case 'it-pa':
      {
        return import('./ItPa-d1ac1ebe.js');
      }
    case 'it-password-invisible':
      {
        return import('./ItPasswordInvisible-6a129dec.js');
      }
    case 'it-password-visible':
      {
        return import('./ItPasswordVisible-4251997a.js');
      }
    case 'it-pencil':
      {
        return import('./ItPencil-81a348d0.js');
      }
    case 'it-piattaforme':
      {
        return import('./ItPiattaforme-d91f0041.js');
      }
    case 'it-pin':
      {
        return import('./ItPin-73ca7052.js');
      }
    case 'it-pinterest-square':
      {
        return import('./ItPinterestSquare-e97b0620.js');
      }
    case 'it-pinterest':
      {
        return import('./ItPinterest-6a8802bd.js');
      }
    case 'it-plug':
      {
        return import('./ItPlug-246a4852.js');
      }
    case 'it-plus-circle':
      {
        return import('./ItPlusCircle-efb25b97.js');
      }
    case 'it-plus':
      {
        return import('./ItPlus-7d44a869.js');
      }
    case 'it-presentation':
      {
        return import('./ItPresentation-571d1680.js');
      }
    case 'it-print':
      {
        return import('./ItPrint-66916ff9.js');
      }
    case 'it-quora-square':
      {
        return import('./ItQuoraSquare-655a5046.js');
      }
    case 'it-quora':
      {
        return import('./ItQuora-1f82a4f6.js');
      }
    case 'it-reddit-square':
      {
        return import('./ItRedditSquare-f7c6601a.js');
      }
    case 'it-reddit':
      {
        return import('./ItReddit-2bde606b.js');
      }
    case 'it-refresh':
      {
        return import('./ItRefresh-78fb2575.js');
      }
    case 'it-restore':
      {
        return import('./ItRestore-cf6ce5df.js');
      }
    case 'it-rss-square':
      {
        return import('./ItRssSquare-fd77dfa7.js');
      }
    case 'it-rss':
      {
        return import('./ItRss-15c2c56f.js');
      }
    case 'it-search':
      {
        return import('./ItSearch-8e9a976e.js');
      }
    case 'it-settings':
      {
        return import('./ItSettings-cdbb77c9.js');
      }
    case 'it-share':
      {
        return import('./ItShare-a5d6912d.js');
      }
    case 'it-slack-square':
      {
        return import('./ItSlackSquare-1a25a89e.js');
      }
    case 'it-slack':
      {
        return import('./ItSlack-c85967e7.js');
      }
    case 'it-snapchat-square':
      {
        return import('./ItSnapchatSquare-14cf44ff.js');
      }
    case 'it-snapchat':
      {
        return import('./ItSnapchat-d40a4ea8.js');
      }
    case 'it-software':
      {
        return import('./ItSoftware-96e60e63.js');
      }
    case 'it-stackexchange-square':
      {
        return import('./ItStackexchangeSquare-3b96db8f.js');
      }
    case 'it-stackexchange':
      {
        return import('./ItStackexchange-d22b6d19.js');
      }
    case 'it-stackoverflow-square':
      {
        return import('./ItStackoverflowSquare-e08335de.js');
      }
    case 'it-stackoverflow':
      {
        return import('./ItStackoverflow-163423d3.js');
      }
    case 'it-star-full':
      {
        return import('./ItStarFull-4fb54b64.js');
      }
    case 'it-star-outline':
      {
        return import('./ItStarOutline-1a55ad7b.js');
      }
    case 'it-team-digitale':
      {
        return import('./ItTeamDigitale-5f79d7f8.js');
      }
    case 'it-telegram':
      {
        return import('./ItTelegram-b791a257.js');
      }
    case 'it-telephone':
      {
        return import('./ItTelephone-dc1a9dd2.js');
      }
    case 'it-tiktok-square':
      {
        return import('./ItTiktokSquare-1c502fd2.js');
      }
    case 'it-tiktok':
      {
        return import('./ItTiktok-e8f79bed.js');
      }
    case 'it-tool':
      {
        return import('./ItTool-554972df.js');
      }
    case 'it-twitter-square':
      {
        return import('./ItTwitterSquare-ffd6493f.js');
      }
    case 'it-twitter':
      {
        return import('./ItTwitter-6a4b3d15.js');
      }
    case 'it-unlocked':
      {
        return import('./ItUnlocked-a3e4a015.js');
      }
    case 'it-upload':
      {
        return import('./ItUpload-2af1c11f.js');
      }
    case 'it-user':
      {
        return import('./ItUser-95e5ca13.js');
      }
    case 'it-video':
      {
        return import('./ItVideo-cb202e13.js');
      }
    case 'it-vimeo-square':
      {
        return import('./ItVimeoSquare-d90512fd.js');
      }
    case 'it-vimeo':
      {
        return import('./ItVimeo-2cc37539.js');
      }
    case 'it-warning-circle':
      {
        return import('./ItWarningCircle-fb154651.js');
      }
    case 'it-warning':
      {
        return import('./ItWarning-fa32327f.js');
      }
    case 'it-whatsapp-square':
      {
        return import('./ItWhatsappSquare-b0d304ba.js');
      }
    case 'it-whatsapp':
      {
        return import('./ItWhatsapp-5855a8e6.js');
      }
    case 'it-wifi':
      {
        return import('./ItWifi-3b6f9734.js');
      }
    case 'it-youtube':
      {
        return import('./ItYoutube-e29ecaca.js');
      }
    case 'it-zoom-in':
      {
        return import('./ItZoomIn-71941590.js');
      }
    case 'it-zoom-out':
      {
        return import('./ItZoomOut-7ed6b13b.js');
      }
    default:
      throw Error(`It should not land here. Requested icon: "${name}"`);
  }
};
function isBundledIcon(name) {
  return name in iconList;
}
const allIcons = /*#__PURE__*/Object.keys(iconList);

const EmptyIcon = _ref => {
  let {
    title,
    titleId,
    ...props
  } = _ref;
  return React__default.createElement("svg", Object.assign({
    xmlns: 'http://www.w3.org/2000/svg',
    viewBox: '0 0 24 24'
  }, props), title ? React__default.createElement("title", {
    id: titleId
  }, title) : null, React__default.createElement("path", {
    fill: 'none',
    d: 'M0 0h24v24H0z'
  }));
};

const iconsList = allIcons;
let iconsCache = {};
/**
 * Preload a list of icons in cache
 * @param icons - the list of icons to preload
 * @returns true if the icons have been preloaded
 */
function preloadIcons(icons) {
  return Promise.all(icons.map(icon => loadIcon(icon))).then(preloadedIcons => {
    preloadedIcons.forEach((_ref, i) => {
      let {
        component
      } = _ref;
      iconsCache[icons[i]] = () => component;
    });
    return true;
  });
}
/**
 * Removes icons from cache
 * @param icon? - the icon to remove, or nothing to clear the whole cache
 * @returns an object containing the removed icons
 */
const clearIconCache = iconName => {
  let deletedItems;
  if (iconName) {
    deletedItems = {
      [iconName]: iconsCache[iconName]
    };
    delete iconsCache[iconName];
  } else {
    deletedItems = {
      ...iconsCache
    };
    iconsCache = {};
  }
  return deletedItems;
};
const Icon = _ref2 => {
  let {
    color = '',
    size = '',
    icon = '',
    title = 'icon',
    className,
    padding = false,
    onIconLoad,
    testId,
    ...attributes
  } = _ref2;
  const [IconComponent, setCurrentIcon] = useState(iconsCache[icon]);
  const classes = classNames('icon', className, {
    [`icon-${color}`]: color,
    [`icon-${size}`]: size,
    'icon-padded': padding
  });
  useEffect(() => {
    if (isBundledIcon(icon) && !iconsCache[icon]) {
      loadIcon(icon).then(_ref3 => {
        let {
          component
        } = _ref3;
        iconsCache[icon] = () => component;
        setCurrentIcon(iconsCache[icon]);
        onIconLoad == null ? void 0 : onIconLoad();
      });
    } else {
      if (IconComponent !== iconsCache[icon]) {
        setCurrentIcon(iconsCache[icon]);
      }
      onIconLoad == null ? void 0 : onIconLoad();
    }
  }, [IconComponent, icon, onIconLoad]);
  if (!isBundledIcon(icon)) {
    // assume it's an image and let the browser do its job
    return React__default.createElement("img", Object.assign({
      src: icon,
      className: classes,
      alt: title,
      "data-testid": testId
    }, attributes));
  }
  if (!IconComponent) {
    return React__default.createElement(EmptyIcon, Object.assign({
      className: classes,
      role: 'img'
    }, attributes, {
      "data-testid": testId
    }));
  }
  return React__default.createElement(IconComponent, Object.assign({
    className: classes,
    role: 'img',
    title: title,
    "data-testid": testId
  }, attributes));
};

const CardCategory = _ref => {
  let {
    iconName,
    date,
    href,
    onClick,
    testId,
    children,
    ...rest
  } = _ref;
  const classes = classNames({
    'category-top': date || ' ',
    'categoryicon-top': iconName
  });
  // Simple category link
  const categoryLink = !iconName && React__default.createElement("a", {
    href: href,
    className: 'category',
    onClick: onClick
  }, children);
  const categoryDate = date && React__default.createElement("span", {
    className: 'data'
  }, date);
  // Category with icon
  const categoryText = iconName && React__default.createElement("span", {
    className: 'text'
  }, children);
  const categoryIcon = iconName && React__default.createElement(Icon, {
    icon: iconName
  });
  return React__default.createElement("div", Object.assign({
    className: classes
  }, rest, {
    "data-testid": testId
  }), categoryLink, categoryIcon, categoryText, categoryDate);
};

const CardTag = _ref => {
  let {
    className,
    tag = 'a',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'card-tag');
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const CardTagsHeader = _ref => {
  let {
    date,
    children,
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('head-tags', className);
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), children, date && React__default.createElement("span", {
    className: 'data'
  }, date));
};

const CardSignature = _ref => {
  let {
    className,
    tag = 'span',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'card-signature');
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const CardFooterCTA = _ref => {
  let {
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'it-card-footer');
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const CardReadMore = _ref => {
  let {
    className,
    text,
    iconName = 'it-arrow-right',
    tag = 'a',
    href,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'read-more');
  return React__default.createElement(Tag, Object.assign({
    className: classes,
    href: href
  }, attributes, {
    "data-testid": testId
  }), React__default.createElement("span", {
    className: 'text'
  }, text), iconName && React__default.createElement(Icon, {
    icon: iconName
  }));
};

const Collapse = _ref => {
  let {
    header = false,
    className,
    navbar,
    megamenu,
    children,
    isOpen = false,
    onOverlayClick,
    cssModule,
    testId,
    ...attributes
  } = _ref;
  const newCssModule = {
    'navbar-collapse': 'navbar-collapsable',
    ...cssModule
  };
  if (megamenu || navbar || header) {
    const classes = classNames(className, 'navbar-collapse', {
      expanded: isOpen
    });
    const style = {
      display: isOpen ? 'block' : 'none'
    };
    return React__default.createElement(Collapse$1, Object.assign({
      className: classes,
      cssModule: newCssModule,
      navbar: navbar,
      style: style,
      "data-testid": testId
    }, attributes), React__default.createElement("div", {
      className: 'overlay',
      style: style,
      onClick: onOverlayClick
    }), React__default.createElement("div", {
      className: 'close-div visually-hidden'
    }, React__default.createElement("button", {
      className: 'btn close-menu',
      type: 'button'
    }, React__default.createElement("span", {
      className: 'it-close'
    }), "close")), megamenu ? React__default.createElement("div", {
      className: 'menu-wrapper'
    }, children) : React__default.createElement(React__default.Fragment, null, children));
  }
  const classes = classNames(className, {
    'link-list-wrapper': header
  });
  return React__default.createElement(Collapse$1, Object.assign({
    className: classes,
    cssModule: newCssModule
  }, attributes, {
    navbar: navbar,
    isOpen: isOpen,
    "data-testid": testId
  }), children);
};

const GridItem = _ref => {
  let {
    tag: Tag = 'div',
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-grid-item-wrapper', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }), children);
};

const GridItemText = _ref => {
  let {
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-griditem-text', className);
  return React__default.createElement("span", Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }), children);
};

const GridItemTextWrapper = _ref => {
  let {
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-griditem-text-wrapper', className);
  return React__default.createElement("span", Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }), children);
};

const GridList = _ref => {
  let {
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-grid-list-wrapper', className);
  return React__default.createElement("div", Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }), children);
};

const GridRow = _ref => {
  let {
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('grid-row', className);
  return React__default.createElement("div", Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }), children);
};

const SLIM = 'slim';
const CENTER = 'center';
const NAVBAR = 'navbar';
const HeaderContext = /*#__PURE__*/createContext({});
const useHeaderContext = () => {
  const {
    type
  } = useContext(HeaderContext);
  return type;
};

const Header = _ref => {
  let {
    className,
    small = false,
    theme = '',
    type,
    testId,
    ...attributes
  } = _ref;
  // use context here as theme
  const classes = classNames(className, {
    [`it-header-${type}-wrapper`]: type,
    'it-small-header': type === CENTER && small,
    [`theme-${theme}`]: type !== NAVBAR && theme,
    'theme-dark-mobile': type === NAVBAR && theme === 'dark',
    'theme-light-desk': type === NAVBAR && theme === 'light'
  });
  return React__default.createElement(HeaderContext.Provider, {
    value: {
      type
    }
  }, React__default.createElement("div", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  })));
};

const Headers = _ref => {
  let {
    className,
    shadow = false,
    sticky = false,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-header-wrapper', {
    'it-shadow': shadow,
    'it-header-sticky': sticky
  }, className);
  if (!sticky) {
    return React__default.createElement("div", Object.assign({
      className: classes
    }, attributes, {
      "data-testid": testId
    }));
  }
  return React__default.createElement(StickyProvider, null, React__default.createElement(Sticky, {
    style: {
      position: 'sticky',
      zIndex: 2
    },
    "data-testid": testId
  }, React__default.createElement("div", Object.assign({
    className: classes
  }, attributes))));
};

const HeaderBrand = _ref => {
  let {
    className,
    href,
    iconName,
    iconAlt,
    children,
    tag = 'a',
    responsive = false,
    testId,
    ...attributes
  } = _ref;
  const type = useHeaderContext();
  const defaultAttributes = {
    tag
  };
  if (type !== CENTER) {
    const classes = classNames('d-lg-block', className, {
      'd-none': !responsive
    });
    return React__default.createElement(NavbarBrand, Object.assign({
      className: classes,
      href: href,
      "data-testid": testId
    }, attributes, defaultAttributes), children);
  }
  return React__default.createElement("div", {
    className: 'it-brand-wrapper',
    "data-testid": testId
  }, React__default.createElement("a", {
    href: href
  }, iconName && React__default.createElement(Icon, {
    icon: iconName,
    title: iconAlt
  }), React__default.createElement("div", {
    className: 'it-brand-text'
  }, React__default.Children.map(children, (child, i) => {
    if (typeof child !== 'object' || child == null || !('props' in child)) {
      return child;
    }
    // convention here: first item is the main title, while others subtext
    const className = classNames(child.props.className, {
      'd-none d-md-block': i
    } // subtext is anything but first element
    );

    const props = {
      className
    };
    return React__default.cloneElement(child, props);
  }))));
};

const HeaderContent = _ref => {
  let {
    className,
    megamenu,
    testId,
    ...attributes
  } = _ref;
  const type = useHeaderContext();
  const classes = classNames(className, {
    'it-header-slim-wrapper-content': type === SLIM,
    'it-header-center-content-wrapper': type === CENTER,
    navbar: type === NAVBAR,
    'has-megamenu': megamenu
  });
  const Content = type === NAVBAR ? React__default.createElement(Navbar, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  })) : React__default.createElement("div", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
  return React__default.createElement(Container, null, React__default.createElement(Row, null, React__default.createElement(Col, null, Content)));
};

const HeaderLinkZone = _ref => {
  let {
    className,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames(className);
  return React__default.createElement("div", {
    className: 'nav-mobile',
    "data-testid": testId
  }, React__default.createElement("nav", Object.assign({
    className: classes
  }, attributes)));
};

const HeaderRightZone = _ref => {
  let {
    className,
    testId,
    ...attributes
  } = _ref;
  const type = useHeaderContext();
  const classes = classNames(className, {
    // BI >= 1.3.6
    'it-header-slim-right-zone': type === SLIM,
    // BI < 1.3.6
    'header-slim-right-zone': type === SLIM,
    'it-right-zone': type !== SLIM
  });
  return React__default.createElement("div", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const HeaderSearch = _ref => {
  let {
    className,
    label,
    href,
    iconName = 'it-search',
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-search-wrapper', className);
  return React__default.createElement("div", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), label && React__default.createElement("span", {
    className: 'd-none d-md-block'
  }, label), React__default.createElement("a", {
    className: 'search-link rounded-icon',
    "aria-label": label,
    href: href
  }, React__default.createElement(Icon, {
    icon: iconName
  })));
};

const HeaderSocialsZone = _ref => {
  let {
    className,
    children,
    label,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-socials d-none d-md-flex', className);
  return React__default.createElement("div", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), label && React__default.createElement("span", null, label), children);
};

const BUTTON = 'button';
const HeaderToggler = _ref => {
  let {
    className,
    tag,
    type,
    testId,
    ...attributes
  } = _ref;
  const HeaderType = useHeaderContext();
  const defaultTag = HeaderType === SLIM ? 'a' : BUTTON;
  const defaultType = HeaderType === SLIM ? undefined : BUTTON;
  const classes = classNames({
    'it-opener d-lg-none': HeaderType === SLIM,
    'custom-navbar-toggler': HeaderType === NAVBAR
  }, className);
  return React__default.createElement(NavbarToggler, Object.assign({
    className: classes
  }, attributes, {
    tag: tag || defaultTag,
    type: type || defaultType,
    href: '#',
    "data-testid": testId
  }));
};

const Hero = _ref => {
  let {
    tag: Tag = 'div',
    small,
    centered,
    overlay,
    overlap,
    className,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-hero-wrapper', className, {
    'it-overlay': overlay,
    ['it-' + overlay]: overlay,
    'it-hero-small-size': small,
    'it-text-centered': centered,
    'it-bottom-overlapping-content': overlap
  });
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const HeroBackground = _ref => {
  let {
    alt,
    testId,
    ...attributes
  } = _ref;
  return React__default.createElement("div", {
    className: 'img-responsive-wrapper',
    "data-testid": testId
  }, React__default.createElement("div", {
    className: 'img-responsive'
  }, React__default.createElement("div", {
    className: 'img-wrapper'
  }, React__default.createElement("img", Object.assign({}, attributes, {
    alt: alt
  })))));
};

const HeroBody = _ref => {
  let {
    children,
    className,
    testId
  } = _ref;
  const classes = classNames('it-hero-text-wrapper', 'bg-dark', className);
  return React__default.createElement(Container, null, React__default.createElement(Row, null, React__default.createElement(Col, null, React__default.createElement("div", {
    className: classes,
    "data-testid": testId
  }, children))));
};

const HeroButton = _ref => {
  let {
    wrapperClassName,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-btn-container', wrapperClassName);
  return React__default.createElement("div", {
    className: classes,
    "data-testid": testId
  }, React__default.createElement(Button, Object.assign({
    size: 'sm'
  }, attributes)));
};

const HeroCategory = _ref => {
  let {
    className,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('it-category', className);
  return React__default.createElement("span", Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }));
};

const HeroTitle = _ref => {
  let {
    tag: Tag = 'h1',
    className,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames(className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }));
};

const InputContainer = _ref => {
  let {
    id,
    infoId,
    testId,
    activeClass,
    label,
    infoTextClass,
    infoText,
    wrapperClass,
    children
  } = _ref;
  return React__default.createElement("div", {
    className: wrapperClass,
    "data-testid": testId
  }, children, React__default.createElement("label", {
    htmlFor: id,
    className: activeClass
  }, label), React__default.createElement("small", {
    id: infoId,
    className: infoTextClass
  }, infoText));
};

function getFormControlClassInternal(_ref) {
  let {
    plaintext,
    staticInput,
    type = 'text',
    addon,
    normalized
  } = _ref;
  const formControlClass = 'form-control';
  if (plaintext || staticInput || normalized) {
    return `${formControlClass}-plaintext`;
  }
  if (type === 'file') {
    return `${formControlClass}-file`;
  }
  if (['radio', 'checkbox'].indexOf(type) > -1) {
    if (addon) {
      return null;
    }
  }
  return formControlClass;
}
function getFormControlClass(props, cssModule) {
  return mapToCssModules(getFormControlClassInternal(props), cssModule);
}
function getInfoTextControlClass(_ref2, cssModule) {
  let {
    invalid
  } = _ref2;
  return mapToCssModules(classNames({
    'form-text': true,
    'form-feedback just-validate-error-label': invalid
  }), cssModule);
}
function getTag(_ref3) {
  let {
    tag,
    plaintext,
    staticInput,
    type = 'text'
  } = _ref3;
  if (tag) {
    return tag;
  }
  if (['radio', 'checkbox'].indexOf(type) > -1) {
    return 'input';
  }
  if (plaintext || staticInput) {
    return 'p';
  }
  return 'input';
}
function getClasses(className, _ref4, cssModule) {
  let {
    isFocused,
    valid,
    invalid,
    bsSize,
    placeholder,
    value,
    label,
    infoText,
    normalized,
    inputPassword,
    formControlClass,
    infoTextControlClass,
    originalWrapperClass
  } = _ref4;
  const hasPlainCondition = placeholder || label || infoText;
  const baseCondition = hasPlainCondition && !normalized && !inputPassword;
  const passwordOnlyCondition = inputPassword && !hasPlainCondition && !normalized;
  const normalizedOnlyCondition = normalized && !hasPlainCondition && !inputPassword;
  const classes = mapToCssModules(classNames(className, {
    'is-invalid': invalid,
    'just-validate-success-field': valid,
    [`form-control-${bsSize}`]: bsSize
  }, formControlClass), cssModule);
  const wrapperClass = mapToCssModules(classNames(className, originalWrapperClass, 'form-group'), cssModule);
  const infoTextClass = mapToCssModules(classNames({
    'valid-feedback': valid,
    'invalid-feedback form-feedback just-validate-error-label': invalid
  }, infoTextControlClass), cssModule);
  const inputClasses = mapToCssModules(classNames(classes, !baseCondition && {
    // we can model here only if stylings
    'form-control-plaintext': normalizedOnlyCondition,
    'form-control': passwordOnlyCondition,
    'input-password': passwordOnlyCondition,
    'focus--mouse': passwordOnlyCondition || normalizedOnlyCondition
  }), cssModule);
  const activeClass = mapToCssModules(classNames({
    active: isFocused || placeholder || value
  }), cssModule);
  return {
    wrapperClass,
    inputClasses,
    activeClass,
    infoTextClass
  };
}
function useFocus(_ref5) {
  let {
    onFocus,
    onBlur
  } = _ref5;
  const [isFocused, setFocus] = useState(false);
  const toggleFocusLabel = useCallback(e => {
    setFocus(true);
    onFocus == null ? void 0 : onFocus(e);
  }, [onFocus]);
  const toggleBlurLabel = useCallback(e => {
    if (e.target.value === '') {
      setFocus(!isFocused);
    }
    onBlur == null ? void 0 : onBlur(e);
  }, [isFocused, onBlur]);
  return {
    toggleFocusLabel,
    toggleBlurLabel,
    isFocused
  };
}

const Input = _ref => {
  let {
    id,
    className,
    cssModule,
    type,
    state,
    tag,
    addon,
    static: staticInput,
    plaintext,
    innerRef,
    label,
    infoText,
    placeholder,
    normalized,
    value,
    wrapperClass: originalWrapperClassOld,
    wrapperClassName: originalWrapperClass,
    size,
    testId,
    noWrapper = false,
    ...attributes
  } = _ref;
  const [isHidden, setHidden] = useState(true);
  const [hasIcon, toggleIcon] = useState(true);
  const {
    toggleFocusLabel,
    toggleBlurLabel,
    isFocused
  } = useFocus({
    onFocus: attributes.onFocus,
    onBlur: attributes.onBlur
  });
  const toggleShow = useCallback(() => {
    setHidden(!isHidden);
    toggleIcon(!hasIcon);
  }, [hasIcon, isHidden]);
  let {
    bsSize,
    valid,
    invalid,
    ...rest
  } = attributes;
  const Tag = getTag({
    tag,
    plaintext,
    staticInput,
    type
  });
  const formControlClass = getFormControlClass({
    plaintext,
    staticInput,
    type,
    addon,
    normalized
  }, cssModule);
  const infoTextControlClass = getInfoTextControlClass({
    valid,
    invalid
  }, cssModule);
  if (state && valid == null && invalid == null) {
    invalid = state === 'danger';
    valid = state === 'success';
  }
  const extraAttributes = {};
  if (size && !isNumber(size)) {
    notifyDeprecation('Please use the prop "bsSize" instead of the "size" to bootstrap\'s input sizing.');
    bsSize = size;
  } else {
    extraAttributes.size = size;
  }
  if (Tag === 'input' || typeof tag !== 'string') {
    extraAttributes.type = type;
  }
  // associate the input field with the help text
  const infoId = id ? `${id}Description` : undefined;
  if (id) {
    extraAttributes['aria-describedby'] = infoId;
  }
  if (attributes.children && !(plaintext || staticInput || type === 'select' || typeof Tag !== 'string' || Tag === 'select')) {
    notifyDeprecation(`Input with a type of "${type}" cannot have children. Please use "value"/"defaultValue" instead.`);
    delete attributes.children;
  }
  const inputPassword = extraAttributes.type === 'password';
  // Styling
  const {
    activeClass,
    infoTextClass,
    inputClasses,
    wrapperClass
  } = getClasses(className, {
    valid,
    invalid,
    bsSize,
    placeholder,
    value,
    label,
    infoText,
    normalized: Boolean(normalized),
    inputPassword,
    formControlClass,
    infoTextControlClass,
    isFocused: isFocused,
    originalWrapperClass: originalWrapperClass || originalWrapperClassOld
  }, cssModule);
  // set of attributes always shared by the Input components
  const sharedAttributes = {
    id,
    onFocus: toggleFocusLabel,
    onBlur: toggleBlurLabel,
    value: value,
    ref: innerRef
  };
  // set of attributes always shared by the wrapper component
  const containerProps = {
    id,
    infoId,
    activeClass,
    label,
    infoTextClass,
    infoText,
    wrapperClass
  };
  if (noWrapper) {
    return React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, {
      className: inputClasses
    }, sharedAttributes, {
      placeholder: placeholder,
      "data-testid": testId
    }));
  }
  if (placeholder) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, sharedAttributes, {
      className: inputClasses,
      placeholder: placeholder,
      "data-testid": testId
    })));
  }
  if (inputPassword) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, sharedAttributes, {
      type: isHidden ? 'password' : 'text',
      className: inputClasses,
      placeholder: placeholder,
      "data-testid": testId
    })), React__default.createElement("span", {
      className: 'password-icon',
      "aria-hidden": 'true'
    }, React__default.createElement(Icon, {
      size: 'sm',
      icon: `it-password-${hasIcon ? 'visible' : 'invisible'}`,
      className: 'password-icon-visible',
      onClick: toggleShow
    })));
  }
  if (normalized) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, sharedAttributes, {
      className: inputClasses,
      "data-testid": testId,
      readOnly: true
    })));
  }
  if (label || infoText) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, sharedAttributes, {
      className: inputClasses,
      "data-testid": testId
    })));
  }
  return React__default.createElement(Tag, Object.assign({}, rest, extraAttributes, {
    className: inputClasses
  }, sharedAttributes, {
    "data-testid": testId
  }));
};

const TextArea = _ref => {
  let {
    id,
    className,
    cssModule,
    innerRef,
    label,
    infoText,
    placeholder,
    normalized,
    value,
    wrapperClassName: originalWrapperClass,
    valid,
    invalid,
    testId,
    ...attributes
  } = _ref;
  const {
    toggleFocusLabel,
    toggleBlurLabel,
    isFocused
  } = useFocus({
    onFocus: attributes.onFocus,
    onBlur: attributes.onBlur
  });
  const infoTextControlClass = getInfoTextControlClass({
    valid,
    invalid
  }, cssModule);
  const extraAttributes = {};
  // associate the input field with the help text
  const infoId = id ? `${id}Description` : undefined;
  if (id) {
    extraAttributes['aria-describedby'] = infoId;
  }
  // Styling
  const {
    activeClass,
    infoTextClass,
    inputClasses,
    wrapperClass
  } = getClasses(className, {
    valid,
    invalid,
    placeholder,
    value,
    label,
    infoText,
    normalized: Boolean(normalized),
    infoTextControlClass,
    isFocused,
    originalWrapperClass
  }, cssModule);
  // set of attributes always shared by the Input components
  const sharedAttributes = {
    id,
    onFocus: toggleFocusLabel,
    onBlur: toggleBlurLabel,
    value,
    ref: innerRef
  };
  // set of attributes always shared by the wrapper component
  const containerProps = {
    id,
    infoId,
    activeClass,
    label,
    infoTextClass,
    infoText,
    wrapperClass
  };
  if (placeholder) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement("textarea", Object.assign({}, attributes, extraAttributes, sharedAttributes, {
      className: inputClasses,
      placeholder: placeholder,
      "data-testid": testId
    })));
  }
  if (normalized) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement("textarea", Object.assign({}, attributes, extraAttributes, sharedAttributes, {
      className: inputClasses,
      readOnly: true,
      "data-testid": testId
    })));
  }
  if (label || infoText) {
    return React__default.createElement(InputContainer, Object.assign({}, containerProps), React__default.createElement("textarea", Object.assign({}, attributes, extraAttributes, sharedAttributes, {
      className: inputClasses,
      "data-testid": testId
    })));
  }
  return React__default.createElement("textarea", Object.assign({}, attributes, extraAttributes, {
    className: inputClasses
  }, sharedAttributes, {
    ref: innerRef,
    "data-testid": testId
  }));
};

const LinkList = _ref => {
  let {
    className,
    wrapperClassName,
    tag = 'div',
    multiline,
    header,
    sublist,
    avatar,
    noWrapper,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('link-list-wrapper', wrapperClassName, {
    multiline: multiline
  });
  const classes = classNames(className, {
    'link-list': !sublist,
    'link-sublist': sublist,
    'avatar-group': avatar
  });
  if (noWrapper) {
    return React__default.createElement("ul", Object.assign({}, attributes, {
      className: classes,
      "data-testid": testId
    }));
  }
  if (sublist) {
    return React__default.createElement(React__default.Fragment, null, header, React__default.createElement("ul", Object.assign({}, attributes, {
      className: classes
    })));
  }
  return React__default.createElement(Tag, {
    className: wrapperClasses,
    "data-testid": testId
  }, header, React__default.createElement("ul", Object.assign({}, attributes, {
    className: classes
  })));
};

const handleDisabledOnClick = e => {
  e.preventDefault();
};
const LinkListItem = _ref => {
  let {
    className,
    active,
    disabled,
    header,
    divider,
    href,
    size,
    tag = 'a',
    wrapperClassName,
    testId,
    children,
    ...attributes
  } = _ref;
  let Tag = tag;
  const classes = classNames(className, {
    active,
    disabled,
    header,
    divider,
    size
  }, 'list-item');
  // Prevent click event when disabled.
  const handlers = {};
  if (disabled) {
    handlers.onClick = handleDisabledOnClick;
  }
  if (header) {
    Tag = 'h3';
  } else if (divider) {
    Tag = 'span';
  }
  if (header && href) {
    return React__default.createElement("li", {
      className: wrapperClassName,
      "data-testid": testId
    }, React__default.createElement(Tag, null, React__default.createElement("a", Object.assign({
      href: href || '#'
    }, attributes, {
      className: classes
    }, handlers), children)));
  }
  return React__default.createElement("li", {
    className: wrapperClassName,
    "data-testid": testId
  }, React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    href: href
  }, handlers), children));
};

const Nav = _ref => {
  let {
    className,
    tag = 'ul',
    vertical = false,
    secondary,
    ...attributes
  } = _ref;
  const classes = classNames(className, {
    'navbar-secondary': secondary
  });
  return React__default.createElement(Nav$1, Object.assign({
    className: classes,
    tag: tag,
    vertical: vertical
  }, attributes));
};

const Megamenu = _ref => {
  let {
    brand,
    className,
    children,
    testId,
    ...attributes
  } = _ref;
  const [openNav, setOpenNav] = useState(false);
  const toggle = () => {
    setOpenNav(!openNav);
  };
  const classes = classNames(className, 'has-megamenu');
  return React__default.createElement(Navbar, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), React__default.createElement(NavbarToggler, {
    className: 'custom-navbar-toggler',
    onClick: toggle
  }, React__default.createElement(Icon, {
    icon: 'it-list',
    size: 'sm'
  })), brand, React__default.createElement(Collapse, {
    isOpen: openNav,
    megamenu: true
  }, React__default.createElement(Nav, {
    navbar: true
  }, children)));
};

const MegamenuItem = _ref => {
  let {
    itemName,
    className,
    children,
    ...attributes
  } = _ref;
  const classes = classNames(className, 'megamenu');
  return React__default.createElement(UncontrolledDropdown, Object.assign({
    nav: true,
    tag: 'li',
    className: classes
  }, attributes), React__default.createElement(DropdownToggle, {
    caret: true,
    nav: true
  }, itemName), React__default.createElement(DropdownMenu, null, children));
};

const MegamenuFooter = _ref => {
  let {
    className,
    children,
    ...attributes
  } = _ref;
  const classes = classNames(className, 'it-megamenu-footer');
  return React__default.createElement("div", Object.assign({
    className: classes
  }, attributes), children);
};

const MegamenuHighlightColumn = _ref => {
  let {
    description,
    className,
    children,
    ...attributes
  } = _ref;
  const classes = classNames(className, 'it-vertical', {
    'it-description': description
  });
  return React__default.createElement(Col, Object.assign({}, attributes), React__default.createElement(Row, {
    className: 'max-height-col'
  }, React__default.createElement(Col, {
    className: classes
  }, description ? React__default.createElement("div", {
    className: 'description-content'
  }, children) : React__default.createElement(React__default.Fragment, null, children))));
};

const Modal = _ref => {
  let {
    withIcon,
    withLinkList,
    popConfirm,
    modalClassName,
    align,
    scrollable,
    className,
    ...props
  } = _ref;
  const isAligned = align != null && ['left', 'right'].includes(align);
  const modalDialogClassnames = classNames(modalClassName, {
    'alert-modal': withIcon,
    'it-dialog-link-list': withLinkList,
    'popconfirm-modal': popConfirm,
    'it-dialog-scrollable': scrollable && isAligned
  });
  const modalClassnames = classNames(className, {
    'modal-dialog-left': align === 'left',
    'modal-dialog-right': align === 'right'
  });
  return React__default.createElement(Modal$1, Object.assign({}, props, {
    scrollable: !isAligned && scrollable,
    className: modalClassnames,
    modalClassName: modalDialogClassnames
  }));
};

const ModalHeader = _ref => {
  let {
    icon,
    className,
    children,
    Util,
    toggle,
    tag: Tag = 'h5',
    wrapTag: WrapTag = 'div',
    closeAriaLabel = 'Close',
    close,
    cssModule,
    ...props
  } = _ref;
  const classes = mapToCssModules(classNames(className, 'modal-header'), cssModule);
  let CloseButton;
  if (!close && toggle) {
    CloseButton = React__default.createElement("button", {
      type: 'button',
      onClick: toggle,
      className: mapToCssModules('btn-close', cssModule),
      "aria-label": closeAriaLabel
    });
  }
  return React__default.createElement(WrapTag, Object.assign({}, props, {
    className: classes
  }), icon != null ? React__default.createElement(Icon, {
    icon: icon
  }) : null, React__default.createElement(Tag, {
    className: mapToCssModules('modal-title', cssModule)
  }, children), close || CloseButton);
};

const ModalBody = props => React__default.createElement(ModalBody$1, Object.assign({}, props));

const ModalFooter = props => React__default.createElement(ModalFooter$1, Object.assign({}, props));

const Pager = _ref => {
  let {
    className,
    tag = 'nav',
    listTag: ListTag = 'ul',
    listClassName,
    children,
    total,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'pagination-wrapper', {
    'pagination-total': total
  });
  const listClasses = classNames(listClassName, 'pagination');
  const {
    ariaLabel,
    label
  } = total || {};
  const totalAriaLabel = ariaLabel ? React__default.createElement("span", {
    className: 'visually-hidden'
  }, ariaLabel) : null;
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), React__default.createElement(ListTag, {
    className: listClasses
  }, children), total ? React__default.createElement("p", null, totalAriaLabel, label) : null);
};

const isCustomLegendObject = legend => {
  return legend != null && typeof legend === 'object' && 'content' in legend;
};
const Rating = _ref => {
  let {
    className,
    inputs,
    legend,
    name,
    readOnly,
    value,
    wrapperClassName,
    testId,
    labelTemplate = value => `Valuta ${value} stelle su 5`,
    onChangeRating = noop,
    ...attributes
  } = _ref;
  // Input data
  // On the DOM we have to go from 5 to 1
  const safeInputs = (inputs || []).reverse();
  // Fields
  const labelFn = labelTemplate;
  const onChange = readOnly ? noop : onChangeRating;
  const wrapperClasses = classNames(wrapperClassName, {
    'rating rating-read-only': readOnly,
    'rating rating-label': legend
  });
  const fieldClasses = classNames(className);
  const extraFieldAttrs = readOnly ? {
    'aria-hidden': true
  } : {};
  // Legend
  const isLegendString = typeof legend === 'string';
  let legendClass = '';
  let legendText = legend;
  if (isCustomLegendObject(legend)) {
    legendClass = classNames({
      'visually-hidden': legend.srOnly
    });
    legendText = legend.content;
  }
  const legendContent = isCustomLegendObject(legend) || isLegendString ? React__default.createElement("legend", {
    className: legendClass
  }, legendText) : legend;
  return React__default.createElement(FormGroup, Object.assign({
    cssModule: {
      'form-group': 'rating'
    },
    tag: 'fieldset',
    className: wrapperClasses,
    "data-testid": testId
  }, attributes), legend && legendContent, safeInputs.map((id, i) => {
    const currentValue = 5 - i;
    return React__default.createElement(Fragment, {
      key: id
    }, React__default.createElement(Input, Object.assign({
      type: 'radio',
      id: id,
      name: name,
      value: String(currentValue),
      cssModule: {
        'form-control': ''
      },
      className: fieldClasses,
      onChange: () => onChange(currentValue, name),
      checked: value === currentValue,
      disabled: readOnly
    }, extraFieldAttrs)), React__default.createElement(Label, {
      className: 'full',
      for: id
    }, React__default.createElement(Icon, {
      icon: 'it-star-full',
      size: 'sm'
    }), React__default.createElement("span", {
      className: 'visually-hidden'
    }, labelFn(currentValue))));
  }));
};

const ResponsiveImage = _ref => {
  let {
    alt,
    testId,
    ...attributes
  } = _ref;
  return React__default.createElement("div", {
    className: 'img-responsive-wrapper',
    "data-testid": testId
  }, React__default.createElement("div", {
    className: 'img-responsive'
  }, React__default.createElement("div", {
    className: 'img-wrapper'
  }, React__default.createElement("img", Object.assign({}, attributes, {
    alt: alt
  })))));
};

const Skiplink = _ref => {
  let {
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'skiplinks');
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const SkiplinkItem = _ref => {
  let {
    className,
    tag = 'a',
    focusable = true,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'visually-hidden', {
    'visually-hidden-focusable': focusable
  });
  // Add an extra href for focusable if the user passes an onClick rather than href prop
  const extraHref = attributes.onClick ? {
    href: '#'
  } : {};
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, extraHref, {
    "data-testid": testId
  }));
};

const Toggle = _ref => {
  let {
    label,
    testId,
    ...rest
  } = _ref;
  return React__default.createElement("div", {
    className: 'toggles',
    "data-testid": testId
  }, React__default.createElement(Label, {
    check: true
  }, label, React__default.createElement(Input$1, Object.assign({}, rest, {
    type: 'checkbox'
  })), React__default.createElement("span", {
    className: 'lever'
  })));
};

const Sidebar = _ref => {
  let {
    className,
    testId,
    tag = 'div',
    secondary = false,
    left = false,
    right = false,
    dark = false,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('sidebar-wrapper', className, {
    'it-line-left-side': left,
    'it-line-right-side': right,
    'theme-dark': dark
  });
  const wrapperClassesLinkList = classNames('sidebar-linklist-wrapper', {
    'linklist-secondary': secondary
  });
  if (secondary) {
    return React__default.createElement(Tag, Object.assign({}, attributes, {
      className: wrapperClassesLinkList,
      "data-testid": testId
    }));
  }
  return React__default.createElement(Tag, {
    className: wrapperClasses,
    "data-testid": testId
  }, React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClassesLinkList
  })));
};

const Progress = _ref => {
  let {
    wrapperClassName,
    className,
    tag = 'div',
    value,
    label,
    indeterminate = false,
    color,
    testId,
    role = 'progressbar',
    ...attributes
  } = _ref;
  const Tag = tag;
  if (!isNumber(value) && !indeterminate) {
    logError(`The passed "value" is not a valid number. You passed "${value}"`);
  }
  const numericValue = Number(value);
  const wrapperClasses = classNames('progress-bar-wrapper');
  const secondaryWrapperClasses = classNames(wrapperClassName === true ? className : wrapperClassName, 'progress', {
    'progress-indeterminate': indeterminate,
    'progress-color': color
  });
  const classes = classNames(className, 'progress-bar', {
    [`bg-${color}`]: color
  });
  if (label && numericValue) {
    return React__default.createElement(Tag, {
      className: wrapperClasses,
      "data-testid": testId
    }, React__default.createElement("div", {
      className: 'progress-bar-label'
    }, React__default.createElement("span", {
      className: 'visually-hidden'
    }, label), numericValue + '%'), React__default.createElement(Tag, {
      className: secondaryWrapperClasses
    }, React__default.createElement("div", Object.assign({}, attributes, {
      className: classes,
      role: 'progressbar',
      style: {
        width: numericValue + '%'
      },
      "aria-valuenow": numericValue,
      "aria-valuemin": 0,
      "aria-valuemax": 100
    }))));
  }
  return React__default.createElement(Tag, {
    className: secondaryWrapperClasses,
    "data-testid": testId
  }, React__default.createElement("div", {
    className: 'progress-bar-label'
  }, React__default.createElement("span", {
    className: 'visually-hidden'
  }, label)), React__default.createElement("div", Object.assign({}, attributes, {
    className: classes,
    role: 'progressbar',
    style: {
      width: numericValue + '%'
    },
    "aria-valuenow": numericValue,
    "aria-valuemin": 0,
    "aria-valuemax": 100
  })));
};

const Spinner = _ref => {
  let {
    className,
    tag = 'span',
    active = false,
    small = false,
    double = false,
    label = 'Caricamento',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('progress-spinner', {
    'progress-spinner-active': active,
    'size-sm': small,
    'progress-spinner-double': double
  });
  const classes = classNames(className, 'visually-hidden');
  if (double) {
    return React__default.createElement(Tag, {
      className: wrapperClasses,
      "data-testid": testId
    }, React__default.createElement("div", {
      className: 'progress-spinner-inner'
    }), React__default.createElement("div", {
      className: 'progress-spinner-inner'
    }), React__default.createElement(Tag, Object.assign({}, attributes, {
      className: classes
    }), label));
  }
  return React__default.createElement(Tag, {
    className: wrapperClasses,
    "data-testid": testId
  }, React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes
  }), label));
};

const BottomNav = _ref => {
  let {
    tag = 'nav',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  return React__default.createElement(Tag, {
    className: 'bottom-nav',
    "data-testid": testId
  }, React__default.createElement("ul", Object.assign({}, attributes)));
};

const BottomNavItem = _ref => {
  let {
    active = false,
    badge,
    alert = false,
    url,
    srText,
    iconName = 'it-comment',
    label,
    tag = 'a',
    onLinkClick,
    link,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const activeClass = classNames({
    active
  });
  const badgeWrapper = Boolean(badge) && React__default.createElement("div", {
    className: 'badge-wrapper'
  }, React__default.createElement("span", {
    className: 'bottom-nav-badge'
  }, badge));
  const alertWrapper = Boolean(alert) && React__default.createElement("div", {
    className: 'badge-wrapper'
  }, React__default.createElement("span", {
    className: 'bottom-nav-alert'
  }));
  return React__default.createElement("li", Object.assign({}, attributes, {
    "data-testid": testId
  }), React__default.createElement(Tag, {
    href: url || link || '#',
    className: activeClass,
    onClick: onLinkClick
  }, badgeWrapper, alertWrapper, React__default.createElement(Icon, {
    icon: iconName
  }), React__default.createElement("span", {
    className: 'bottom-nav-label'
  }, label, srText ? React__default.createElement("span", {
    className: 'visually-hidden'
  }, srText) : null)));
};

const ThumbNav = _ref => {
  let {
    isSmall = false,
    fixedWidth = false,
    isVertical = false,
    noZoomOnHover = false,
    rowItems,
    overlayOnHover,
    position,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames('thumb-nav', {
    'thumb-nav-fixed': fixedWidth,
    'thumb-nav-small': isSmall,
    'thumb-nav-vertical': isVertical || position === 'left' || position === 'right',
    'thumb-nav-nozoom': noZoomOnHover,
    [`thumb-nav-${overlayOnHover}`]: overlayOnHover,
    [`thumb-nav-${position}`]: position,
    'thumb-nav-auto': rowItems != null,
    [`thumb-nav-auto-${rowItems}`]: rowItems != null
  });
  return React__default.createElement("ul", Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const ThumbNavItem = _ref => {
  let {
    active = false,
    targetUrl,
    imageUrl,
    actionDescription,
    testId,
    ...attributes
  } = _ref;
  const classes = classNames({
    active: active
  }, 'ratio', 'ratio-3x2');
  return React__default.createElement("li", Object.assign({}, attributes, {
    "data-testid": testId
  }), React__default.createElement("img", {
    src: 'https://picsum.photos/240/160?image=1056',
    className: 'thumb-nav-resizer',
    "aria-hidden": 'true',
    alt: ''
  }), React__default.createElement("a", {
    href: targetUrl,
    className: classes
  }, React__default.createElement("img", {
    src: imageUrl,
    alt: actionDescription
  })));
};

const CookieBar = _ref => {
  let {
    tag = 'div',
    className,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames('cookiebar show', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClasses,
    "data-testid": testId
  }));
};

const CookieBarButtons = _ref => {
  let {
    className,
    tag = 'div',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const buttonClasses = classNames(className, 'cookiebar-buttons');
  return React__default.createElement(Tag, Object.assign({
    className: buttonClasses
  }, attributes, {
    "data-testid": testId
  }));
};

const CookieBarButton = _ref => {
  let {
    tag = 'button',
    className,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const activeClass = classNames(className, 'cookiebar-btn');
  return React__default.createElement(Tag, Object.assign({
    className: activeClass
  }, attributes, {
    "data-testid": testId
  }));
};

const Chip = _ref => {
  let {
    className,
    color = '',
    tag = 'div',
    simple = false,
    large = false,
    disabled = false,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('chip', className, {
    'chip-simple': simple,
    'chip-lg': large,
    'chip-disabled': disabled,
    [`chip-${color}`]: color
  });
  return React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }));
};

const ChipLabel = _ref => {
  let {
    className,
    tag = 'span',
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames(className, 'chip-label');
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    "data-testid": testId
  }));
};

const defaultFonts = ['Titillium Web:300,400,600,700:latin-ext', 'Lora:400,700:latin-ext', 'Roboto Mono:400,700:latin-ext'];
function useFontLoader(_ref) {
  let {
    fonts
  } = _ref;
  useEffect(() => {
    if (typeof window !== 'undefined') {
      const WebFont = require('webfontloader');
      WebFont.load({
        custom: {
          families: [...defaultFonts, ...(fonts || [])]
        }
      });
    }
  }, [fonts]);
}
const FontLoader = props => {
  useFontLoader(props);
  return null;
};

const Dimmer = _ref => {
  let {
    icon,
    color,
    className,
    wrapperClassName,
    testId,
    ...attributes
  } = _ref;
  const {
    children,
    ...rest
  } = attributes;
  const classes = classNames('dimmer', wrapperClassName === true ? className : wrapperClassName, {
    [`dimmer-${color}`]: color
  });
  const innerClasses = classNames('dimmer-inner', className);
  const dimmerIcon = icon && React__default.createElement("div", {
    className: 'dimmer-icon'
  }, React__default.createElement(Icon, {
    icon: icon
  }));
  return React__default.createElement("div", Object.assign({
    className: classes
  }, rest, {
    style: {
      display: 'flex'
    },
    "data-testid": testId
  }), React__default.createElement("div", Object.assign({
    className: innerClasses
  }, rest), dimmerIcon, children));
};

const DimmerButtons = _ref => {
  let {
    color,
    className,
    single = false,
    dark = true,
    testId,
    ...attributes
  } = _ref;
  const {
    children,
    ...rest
  } = attributes;
  const classes = classNames('dimmer-buttons', className, {
    'bg-dark': dark,
    'single-button': single
  });
  return React__default.createElement("div", Object.assign({
    className: classes
  }, rest, {
    "data-testid": testId
  }), children);
};

const addTime = (value, maxValue) => {
  const currTime = Number(value);
  return currTime >= maxValue ? value : (currTime + 1).toString();
};
const subtractTime = (value, minValue) => {
  const currTime = Number(value);
  return currTime <= minValue ? value : (currTime - 1).toString();
};
const formatTime = value => `0${value}`.substr(-2);
const TimeInputContainer = _ref => {
  let {
    wrapperClass,
    children,
    label,
    id,
    infoText,
    button,
    infoTextClass,
    invalid
  } = _ref;
  const infoId = id ? `${id}Description` : undefined;
  const activeClass = 'active';
  return React__default.createElement("div", {
    className: classNames(wrapperClass)
  }, React__default.createElement("div", {
    className: 'input-group'
  }, children, React__default.createElement("label", {
    htmlFor: id,
    className: classNames(activeClass, {
      'error-label': invalid
    })
  }, label), React__default.createElement("div", {
    id: infoId,
    className: infoTextClass
  }, infoText), React__default.createElement("div", {
    className: 'input-group-append'
  }, button)));
};
const TimeInput = _ref2 => {
  let {
    dark = false,
    onBlur = noop,
    label,
    controlsLabel,
    invalid = false,
    value = '',
    id,
    placeholder,
    srText,
    hoursLabel,
    minutesLabel,
    increaseHoursLabel,
    increaseMinutesLabel,
    decreaseHoursLabel,
    decreaseMinutesLabel,
    testId,
    ...attributes
  } = _ref2;
  const [initialHours, initialMinutes] = value.split(':');
  const [isOpen, setIsOpen] = useState(false);
  const [hours, setHours] = useState(initialHours || '00');
  const [minutes, setMinutes] = useState(initialMinutes || '00');
  const [time, setTime] = useState(initialHours && initialMinutes ? `${initialHours}:${initialMinutes}` : '');
  const [isFocused, toggleFocus] = useState(false);
  const button = React__default.createElement("button", {
    type: 'button',
    className: 'btn-time',
    onClick: () => {
      setIsOpen(!isOpen);
      if (isOpen) onBlur(time);
    }
  }, React__default.createElement(Icon, {
    icon: 'it-clock'
  }));
  const onHoursChange = value => {
    const formattedValue = formatTime(value);
    setHours(isNaN(Number(formattedValue)) ? `00` : formattedValue);
    setTime(`${formattedValue}:${minutes}`);
  };
  const onMinutesChange = value => {
    const formattedValue = formatTime(value);
    setMinutes(isNaN(Number(formattedValue)) ? `00` : formattedValue);
    setTime(`${hours}:${formattedValue}`);
  };
  const onTimeChange = value => {
    const [hours, minutes] = value.split(':');
    onHoursChange(hours == null ? void 0 : hours.trim());
    onMinutesChange(minutes == null ? void 0 : minutes.trim());
    setTime(value);
  };
  const infoTextControlClass = getInfoTextControlClass(attributes, attributes.cssModule);
  const {
    infoTextClass,
    wrapperClass
  } = getClasses(attributes.className, {
    ...attributes,
    normalized: Boolean(attributes.normalized),
    inputPassword: false,
    formControlClass: 'form-control',
    infoTextControlClass,
    isFocused,
    originalWrapperClass: attributes.wrapperClassName || attributes.wrapperClass
  }, attributes.cssModule);
  return React__default.createElement("div", {
    className: classNames('it-timepicker-wrapper', {
      'theme-dark': dark
    }),
    "data-testid": testId
  }, React__default.createElement("section", {
    className: 'time-spinner'
  }, React__default.createElement("div", {
    className: 'error_container',
    role: 'alert',
    "aria-atomic": 'true'
  }), React__default.createElement("fieldset", null, React__default.createElement("legend", null, React__default.createElement("span", {
    className: 'visually-hidden'
  }, srText)), React__default.createElement("div", null, React__default.createElement("div", {
    className: 'calendar-input-container'
  }, React__default.createElement(TimeInputContainer, {
    wrapperClass: wrapperClass,
    infoTextClass: infoTextClass,
    label: label,
    infoText: attributes.infoText,
    id: id,
    button: button,
    invalid: invalid
  }, React__default.createElement(Input, Object.assign({}, attributes, {
    type: 'text',
    label: label,
    id: id,
    placeholder: placeholder,
    value: time,
    onFocus: () => {
      setIsOpen(false);
      toggleFocus(true);
    },
    onChange: e => onTimeChange(e.target.value),
    invalid: invalid,
    onBlur: () => {
      toggleFocus(false);
      onBlur(time);
    },
    noWrapper: true
  })))))), React__default.createElement("div", {
    className: 'spinner-control',
    "aria-hidden": 'true',
    role: 'region',
    "aria-label": controlsLabel,
    tabIndex: -1,
    style: {
      display: isOpen ? 'block' : 'none'
    }
  }, React__default.createElement("div", {
    className: 'spinner-hour spinner'
  }, React__default.createElement(Input, {
    className: 'spinnerHour form-control',
    "aria-label": hoursLabel,
    type: 'number',
    value: hours,
    role: 'spinbutton',
    maxLength: 2,
    "aria-valuenow": Number(hours),
    "aria-valuemax": 23,
    "aria-valuemin": 0,
    onChange: e => onHoursChange(e.target.value)
  }), React__default.createElement("div", {
    className: 'button-wrapper'
  }, React__default.createElement("button", {
    type: 'button',
    className: 'button-hour btnHourUp',
    "aria-label": increaseHoursLabel,
    "aria-hidden": 'true',
    tabIndex: -1,
    onClick: () => onHoursChange(addTime(hours, 23))
  }, React__default.createElement("span", {
    className: 'icon-up'
  })), React__default.createElement("button", {
    type: 'button',
    className: 'button-hour btnHourDown',
    "aria-label": decreaseHoursLabel,
    "aria-hidden": 'true',
    tabIndex: -1,
    onClick: () => onHoursChange(subtractTime(hours, 0))
  }, React__default.createElement("span", {
    className: 'icon-down'
  })))), React__default.createElement("div", {
    className: 'spinner-min spinner'
  }, React__default.createElement(Input, {
    className: 'spinnerMin form-control',
    "aria-label": minutesLabel,
    type: 'number',
    value: minutes,
    role: 'spinbutton',
    maxLength: 2,
    "aria-valuenow": Number(minutes),
    "aria-valuemax": 59,
    "aria-valuemin": 0,
    onChange: e => onMinutesChange(e.target.value)
  }), React__default.createElement("div", {
    className: 'button-wrapper'
  }, React__default.createElement("button", {
    type: 'button',
    className: 'btnMinUp button-minute',
    "aria-label": increaseMinutesLabel,
    "aria-hidden": 'true',
    tabIndex: -1,
    onClick: () => onMinutesChange(addTime(minutes, 59))
  }, React__default.createElement("span", {
    className: 'icon-up'
  })), React__default.createElement("button", {
    type: 'button',
    className: 'btnMinDown button-minute',
    "aria-label": decreaseMinutesLabel,
    "aria-hidden": 'true',
    tabIndex: -1,
    onClick: () => onMinutesChange(subtractTime(minutes, 0))
  }, React__default.createElement("span", {
    className: 'icon-down'
  })))))));
};

const Timeline = props => {
  const {
    className,
    testId,
    ...attributes
  } = props;
  const {
    children,
    ...rest
  } = attributes;
  const timelineWrapper = classNames(className, 'it-timeline-wrapper');
  return React__default.createElement("div", Object.assign({
    className: timelineWrapper
  }, rest, {
    "data-testid": testId
  }), children);
};

const TimelinePin = _ref => {
  let {
    iconName = 'it-code-circle',
    icon = 'it-code-circle',
    label = ' ',
    past,
    now,
    nowText,
    testId,
    className,
    ...attributes
  } = _ref;
  const {
    children,
    ...rest
  } = attributes;
  const classes = classNames('timeline-element', className);
  const innerClasses = classNames('it-pin-wrapper', className, {
    'it-evidence': past,
    'it-now': now
  });
  const pinIcon = React__default.createElement("div", {
    className: 'pin-icon'
  }, React__default.createElement(Icon, {
    icon: iconName || icon
  }));
  const pinLabel = React__default.createElement("div", {
    className: 'pin-text'
  }, React__default.createElement("span", null, label));
  const pinTextNow = now && React__default.createElement("span", {
    className: 'it-now-label d-none d-lg-flex'
  }, nowText);
  return React__default.createElement("div", {
    className: classes,
    "data-testid": testId
  }, pinTextNow, React__default.createElement("div", Object.assign({
    className: innerClasses
  }, rest), pinIcon, pinLabel), children);
};

const black = '#000';
const primary = '#06c';
const primaryDark = '#435a70';
const primaryDarker = '#17324d';
// Types here depend of react-select internal emotion dep + more parametric stuff
// @TODO: fix it this way for now, will review later on
const styles = {
  container: provided => ({
    ...provided,
    height: '2.5rem'
  }),
  control: provided => ({
    ...provided,
    height: '2.5rem',
    borderRadius: '0',
    borderLeft: 'none',
    borderRight: 'none',
    borderTop: 'none',
    borderBottom: `solid ${primaryDark} 1px`,
    boxShadow: 'none',
    '&:hover': {
      borderBottom: `solid ${primaryDark} 1.25px`
    } // border style on hover
  }),

  dropdownIndicator: provided => ({
    ...provided,
    fill: primaryDark
  }),
  option: (provided, _ref) => {
    let {
      isDisabled,
      isFocused,
      isSelected
    } = _ref;
    return {
      ...provided,
      background: 'white',
      textDecoration: isFocused || isSelected ? 'underline' : 'none',
      color: isSelected ? primaryDarker : primary,
      cursor: isDisabled ? 'not-allowed' : 'pointer'
    };
  },
  placeholder: provided => ({
    ...provided,
    fill: primaryDark
  }),
  singleValue: provided => ({
    ...provided,
    color: black,
    fontWeight: 'bold'
  }),
  valueContainer: provided => ({
    ...provided,
    height: '2.5rem'
  })
};

const DropdownIndicator = props => {
  return React__default.createElement(components.DropdownIndicator, Object.assign({}, props), React__default.createElement(Icon, {
    icon: 'it-arrow-down-triangle',
    "aria-hidden": true
  }));
};
const Option = props => {
  return React__default.createElement("div", {
    className: 'select-pill text-primary'
  }, React__default.createElement(components.Option, Object.assign({}, props)));
};
const CustomClearText = _ref => {
  let {
    clearText
  } = _ref;
  return React__default.createElement(React__default.Fragment, null, clearText);
};
const Select = _ref2 => {
  let {
    clearText = 'Annulla',
    icon = false,
    ...props
  } = _ref2;
  // @TODO: move it outside when migrating to hooks
  const ClearIndicator = clearIndicatorProps => {
    const {
      children = React__default.createElement(CustomClearText, {
        clearText: clearText
      }),
      innerProps: {
        ref,
        ...restInnerProps
      }
    } = clearIndicatorProps;
    return React__default.createElement("div", Object.assign({
      className: 'select-pill text-primary'
    }, restInnerProps, {
      ref: ref
    }), React__default.createElement("div", {
      style: {
        padding: '0px 5px'
      }
    }, children));
  };
  const selectComponents = {
    ...props.components,
    Option,
    DropdownIndicator,
    IndicatorSeparator: null
  };
  if (props.isClearable) {
    selectComponents.ClearIndicator = ClearIndicator;
  }
  return React__default.createElement(SelectBase, Object.assign({}, props, {
    components: selectComponents,
    styles: styles
  }));
};

const StepperHeader = _ref => {
  var _children$props;
  let {
    tag = 'div',
    testId,
    className,
    children,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('steppers-header', className);
  // @ts-ignore not recognize children's props
  const isMobile = (children == null ? void 0 : (_children$props = children.props) == null ? void 0 : _children$props.variant) === 'mobile';
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClass,
    "data-testid": testId
  }), isMobile ? React__default.createElement("span", null, children) : React__default.createElement("ul", null, children));
};

const StepperContainer = _ref => {
  let {
    tag = 'div',
    mobile,
    dark,
    testId,
    className,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('steppers', className, {
    'bg-dark': dark
  }, {
    'mobile-examples': mobile
  });
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClass,
    "data-testid": testId
  }));
};

const variants = {
  confirmed: 'confirmed',
  active: 'active',
  done: 'done',
  mobile: 'steppers-index',
  // @deprecated
  'steppers-index': 'steppers-index'
};
const StepperHeaderElement = _ref => {
  let {
    tag = 'li',
    variant,
    appendIcon,
    prependIcon,
    icon,
    iconName,
    noLine,
    stepperNumber,
    testId,
    children,
    className,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClasses = classNames(variant ? variants[variant] : '', className, {
    'no-line': noLine
  });
  const iconClass = classNames('icon', 'steppers-success');
  const spanClass = classNames('steppers-number');
  const iconToAppend = appendIcon || icon;
  const iconToPrepend = prependIcon || iconName;
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClasses,
    "data-testid": testId
  }), iconToPrepend && React__default.createElement(Icon, {
    icon: iconToPrepend
  }), stepperNumber && React__default.createElement("span", {
    className: spanClass
  }, stepperNumber), children, iconToAppend && React__default.createElement(Icon, {
    icon: iconToAppend,
    className: iconClass
  }));
};

const StepperNav = _ref => {
  let {
    tag = 'nav',
    testId,
    className,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('steppers-nav', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClass,
    "data-testid": testId
  }));
};

const StepperDots = _ref => {
  let {
    tag = 'ul',
    className,
    testId,
    ...attributes
  } = _ref;
  const Tag = tag;
  const wrapperClass = classNames('steppers-dots', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: wrapperClass,
    "data-testid": testId
  }));
};

const contentStyleLight = {
  height: '400px',
  border: '2px dashed #eee',
  background: '#fafafa',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  color: '#333'
};
const contentStyleDark = {
  height: '400px',
  border: '2px dashed #eee',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  color: '#EEE',
  borderColor: '#aaa',
  background: '#17324d',
  opacity: 0.5
};
const StepperContent = _ref => {
  let {
    tag = 'div',
    className,
    dark,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('steppers-content', className);
  return React__default.createElement(Tag, Object.assign({}, attributes, {
    className: classes,
    style: dark && contentStyleDark || contentStyleLight,
    "aria-live": 'polite'
  }));
};

const Section = _ref => {
  let {
    color,
    image,
    testId,
    wrapperClassName,
    className,
    children,
    neutral,
    muted,
    ...rest
  } = _ref;
  const classes = classNames('section', wrapperClassName === true ? className : wrapperClassName, {
    [`section-${color}`]: color,
    'section-image': image
  });
  if (neutral || muted) {
    notifyDeprecation(`Please use the prop "color" instead of the "${neutral ? 'neutral' : 'muted'}" for the Section component.`);
  }
  // have them separated from the classes above or these will conflict with the color prop
  // concatenate them at the end. Worst case a duplicate class will appear
  const deprecatedClasses = classNames({
    'section-neutral': neutral,
    'section-muted': muted
  });
  const innerClasses = classNames('section-content', className);
  const styleClass = {
    backgroundImageClass: image ? {
      backgroundImage: `url(${image})`
    } : {}
  };
  const finalWrapperClassName = classNames(classes, deprecatedClasses);
  return React__default.createElement("div", Object.assign({
    className: finalWrapperClassName,
    style: styleClass.backgroundImageClass,
    "data-testid": testId
  }, rest), React__default.createElement("div", {
    className: innerClasses
  }, children));
};

const PositionContext = /*#__PURE__*/createContext(undefined);
function usePosition() {
  const context = useContext(PositionContext);
  return context;
}

const getBorderStyleFix = fix => {
  const borderReset = ['top', 'bottom', 'right', 'left'].filter(curPosition => fix === 'left' ? curPosition !== 'right' : curPosition !== 'left').map(borderPosition => `border${borderPosition[0].toUpperCase() + borderPosition.substring(1)}`);
  const customStyle = {};
  for (const borderPos of borderReset) {
    customStyle[borderPos] = 'none';
  }
  return customStyle;
};
function pickIcon(state) {
  switch (state) {
    case 'error':
      return 'it-close-circle';
    case 'info':
      return 'it-info-circle';
    case 'warning':
      return 'it-error';
    case 'success':
      return 'it-check-circle';
    default:
      return undefined;
  }
}
function NotificationElement(_ref) {
  let {
    closeToast,
    toastProps,
    title,
    body,
    options
  } = _ref;
  const globalFix = usePosition();
  const {
    icon: userIcon,
    state,
    fix: localFix,
    dismissable
  } = options;
  const fixPosition = localFix == null && globalFix ? globalFix : localFix || globalFix;
  const {
    autoClose,
    style
  } = toastProps;
  const content = typeof body === 'string' ? React__default.createElement("p", null, body) : body;
  const icon = userIcon || pickIcon(state);
  const borderFixes = getBorderStyleFix(fixPosition);
  const wrapperClass = classNames('notification', state, {
    [`${fixPosition}-fix`]: fixPosition,
    'with-icon': icon,
    dismissable: dismissable || !autoClose
  });
  // Need to override some toast styling here
  const customStyle = {
    ...style,
    ...borderFixes,
    // force a display as the notification class has a "display: none" set
    display: 'block'
  };
  return React__default.createElement("div", {
    className: wrapperClass,
    style: customStyle
  }, React__default.createElement("h5", null, title, icon ? React__default.createElement(Icon, {
    icon: icon
  }) : null), content, (!autoClose || dismissable) && React__default.createElement(Button, {
    className: 'notification-close',
    onClick: closeToast
  }, React__default.createElement(Icon, {
    icon: 'it-close'
  }), React__default.createElement("span", {
    className: 'visually-hidden'
  }, "Chiudi notifica: ", title)));
}
/**
 * Internal use only. Exported for documentation purposes.
 * @internal
 */
const createNotification = (title, body, options, closeToast, toastProps) => React__default.createElement(NotificationElement, {
  title: title,
  body: body,
  options: options,
  closeToast: closeToast,
  toastProps: toastProps
});

const dummyTransition = /*#__PURE__*/cssTransition({
  enter: '',
  exit: ''
});
const Notification = props => {
  const {
    toastRef,
    eventHandlers
  } = useToast({
    ...props,
    transition: dummyTransition
  });
  const {
    children,
    autoClose,
    onClick,
    role,
    toastId,
    deleteToast,
    closeToast,
    isIn
  } = props;
  const customStyle = {
    display: isIn ? 'block' : 'none'
  };
  useEffect(() => {
    if (!isIn) deleteToast();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isIn]);
  useEffect(() => {
    let timer;
    if (autoClose) {
      timer = setTimeout(() => closeToast(), autoClose);
    }
    return () => {
      if (timer != null) {
        clearTimeout(Number(timer));
      }
    };
  }, [autoClose, closeToast]);
  return React__default.createElement("div", Object.assign({
    id: toastId,
    onClick: onClick
  }, eventHandlers, {
    style: customStyle,
    ref: toastRef
  }, isIn && {
    role: role
  }), children);
};

const KitTransition = /*#__PURE__*/cssTransition({
  enter: `d-block`,
  exit: `d-none`,
  appendPosition: false
});
const NotificationManager = props => {
  const customStyle = {
    ...props.style,
    ...getBorderStyleFix(props.fix)
  };
  const hookProps = {
    autoClose: props.duration ?? 6000,
    closeOnClick: props.closeOnClick ?? true,
    hideProgressBar: true,
    transition: KitTransition,
    rtl: false,
    pauseOnHover: true,
    pauseOnFocusLoss: true,
    newestOnTop: false,
    draggable: false,
    role: 'alert',
    style: customStyle,
    enableMultiContainer: props.containerId != null // enable multi container when an explicit id is passed
  };

  const {
    getToastToRender,
    containerRef,
    isToastActive
  } = useToastContainer(hookProps);
  const {
    containerId,
    style,
    fix
  } = props;
  return React__default.createElement(PositionContext.Provider, {
    value: fix
  }, React__default.createElement("div", {
    ref: containerRef,
    id: containerId,
    style: style
  }, getToastToRender((_, toastList) => {
    return toastList.map(_ref => {
      let {
        content,
        props: toastProps
      } = _ref;
      return React__default.createElement(Notification, Object.assign({}, toastProps, {
        isIn: isToastActive(toastProps.toastId),
        key: `notification-${toastProps.key}`
      }), content);
    });
  })));
};

function notify(title, bodyOrOptions, options) {
  let body = isReactChild(bodyOrOptions) ? bodyOrOptions : undefined;
  const safeOptions = isReactChild(bodyOrOptions) ? {
    ...options
  } : bodyOrOptions || {};
  const NotificationContent = createNotification(title, body, safeOptions);
  const internalOptions = {
    ...safeOptions,
    autoClose: safeOptions.duration
  };
  return toast(NotificationContent, internalOptions);
}
function isReactChild(el) {
  return el != null && (typeof el === 'string' || typeof el === 'number' || 'type' in el);
}
notify.dismiss = id => toast.dismiss(id);

const SizeContext = /*#__PURE__*/createContext(undefined);
const Toolbar = _ref => {
  let {
    tag = 'nav',
    size,
    testId,
    children,
    vertical,
    ...attributes
  } = _ref;
  const Tag = tag;
  const classes = classNames('toolbar', {
    [`toolbar-${size}`]: size && size !== 'large',
    'toolbar-vertical': vertical
  });
  return React__default.createElement(SizeContext.Provider, {
    value: size || 'large'
  }, React__default.createElement(Tag, Object.assign({
    className: classes
  }, attributes, {
    "data-testid": testId
  }), React__default.createElement("ul", null, children)));
};

const disabledMessage = ' elemento disabilitato';
function ToolbarItemLabel(_ref) {
  let {
    label,
    size,
    disabled,
    badge
  } = _ref;
  const showSrText = size && size !== 'large';
  if (disabled) {
    if (!label || showSrText) {
      return React__default.createElement("span", {
        className: 'visually-hidden'
      }, disabledMessage);
    }
    return React__default.createElement(React__default.Fragment, null, React__default.createElement("span", {
      className: 'toolbar-label'
    }, label), React__default.createElement("span", {
      className: 'visually-hidden'
    }, disabledMessage));
  }
  if (!label) {
    return null;
  }
  return showSrText ? React__default.createElement("span", {
    className: 'visually-hidden'
  }, label) : React__default.createElement("span", {
    className: 'toolbar-label'
  }, label, badge != null && badge.label ? React__default.createElement("span", {
    className: 'visually-hidden'
  }, badge.label) : null);
}
const ToolbarItem = _ref2 => {
  let {
    active = false,
    badge,
    url,
    iconName,
    label,
    tag = 'a',
    disabled,
    testId,
    srText,
    dropdown,
    dropdownProps,
    children,
    showMore,
    onClick,
    isDropdownOpen,
    ...attributes
  } = _ref2;
  const Tag = tag;
  const size = useContext(SizeContext);
  const activeClass = classNames({
    active,
    disabled
  });
  const ariaAttributes = {
    ...(disabled && {
      'aria-disabled': true
    })
  };
  const badgeObject = typeof badge === 'number' ? {
    value: badge,
    label: srText || '',
    srText: srText || ''
  } : badge;
  const toolbarItemContent = React__default.createElement(React__default.Fragment, null, badgeObject ? React__default.createElement("div", {
    className: 'badge-wrapper'
  }, React__default.createElement("span", {
    className: 'toolbar-badge'
  }, size !== 'large' ? null : badgeObject.value), size !== 'large' && React__default.createElement("span", {
    className: 'visually-hidden'
  }, badgeObject.srText)) : null, React__default.createElement(Icon, {
    icon: iconName,
    size: size === 'small' ? 'sm' : ''
  }), React__default.createElement(ToolbarItemLabel, {
    label: label,
    size: size,
    disabled: disabled,
    badge: badgeObject
  }));
  if (dropdown) {
    return React__default.createElement("li", null, React__default.createElement(Dropdown, Object.assign({}, dropdownProps, {
      toggle: onClick,
      isOpen: isDropdownOpen
    }), React__default.createElement(DropdownToggle, {
      disabled: disabled,
      caret: true,
      className: classNames('btn-dropdown', {
        'toolbar-more': showMore
      }),
      color: ''
    }, toolbarItemContent), children));
  }
  return React__default.createElement("li", null, React__default.createElement(Tag, Object.assign({
    href: url || '#',
    className: activeClass,
    "data-testid": testId
  }, attributes, ariaAttributes, {
    onClick: onClick
  }), toolbarItemContent));
};

const ToolbarDividerItem = () => React__default.createElement("li", {
  className: 'toolbar-divider',
  "aria-hidden": true
});

export { Accordion, AccordionBody, AccordionHeader, AccordionItem, Alert, AvatarContainer, AvatarExtraText, AvatarGroupContainer, AvatarIcon, AvatarPresence, AvatarStatus, AvatarWrapper, Badge, BottomNav, BottomNavItem, Breadcrumb, Button, Callout, CalloutText, CalloutTitle, Card, CardBody, CardCategory, CardFooterCTA, CardReadMore, CardSignature, CardTag, CardTagsHeader, CardText, CardTitle, Chip, ChipLabel, Collapse, CookieBar, CookieBarButton, CookieBarButtons, Dimmer, DimmerButtons, FontLoader, Forward, GridItem, GridItemText, GridItemTextWrapper, GridList, GridRow, Header, HeaderBrand, HeaderContent, HeaderLinkZone, HeaderRightZone, HeaderSearch, HeaderSocialsZone, HeaderToggler, Headers, Hero, HeroBackground, HeroBody, HeroButton, HeroCategory, HeroTitle, Icon, Input, InputContainer, LinkList, LinkListItem, Megamenu, MegamenuFooter, MegamenuHighlightColumn, MegamenuItem, Modal, ModalBody, ModalFooter, ModalHeader, Nav, NotificationManager, Pager, Progress, Rating, ResponsiveImage, Section, Select, Sidebar, Skiplink, SkiplinkItem, Spinner, StepperContainer, StepperContent, StepperDots, StepperHeader, StepperHeaderElement, StepperNav, TextArea, ThumbNav, ThumbNavItem, TimeInput, Timeline, TimelinePin, Toggle, Toolbar, ToolbarDividerItem, ToolbarItem, clearIconCache, createNotification, iconsList as icons, notify, preloadIcons, useFontLoader };
//# sourceMappingURL=index.js.map
